@@ -22,15 +22,15 @@
 #include "about.hh"
 #include <string>
 #include "cgpl.h"
-#include <aguix/aguix.h>
-#include <aguix/utf8.hh>
+#include "aguix/aguix.h"
+#include "aguix/utf8.hh"
 #include "worker.h"
 #include "workerversion.h"
-#include <aguix/acontainerbb.h>
-#include <aguix/util.h>
-#include <aguix/awindow.h>
-#include <aguix/button.h>
-#include <aguix/fieldlistview.h>
+#include "aguix/acontainerbb.h"
+#include "aguix/util.h"
+#include "aguix/awindow.h"
+#include "aguix/button.h"
+#include "aguix/fieldlistview.h"
 #include "datei.h"
 #include "worker_locale.h"
 
