@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -286,7 +286,9 @@ public:
                    XDNDFINISHED,
                    XDNDSELECTION,
                    XDNDPROXY,
-                   XDNDAWARE
+                   XDNDAWARE,
+                   CARDINAL_ATOM,
+                   NET_WM_ICON_ATOM
     } atom_name_t;
   Atom getAtom( atom_name_t name ) const;
 
@@ -372,6 +374,11 @@ public:
     int getCurrentUserColorInstance() const;
 
     bool isModifierPressed( unsigned int mask );
+
+    void setStandardIconData( const unsigned long *data,
+                              size_t data_length );
+    bool getStandardIconData( const unsigned long **return_data,
+                              size_t *return_data_length ) const;
 private:
   Display *dsp;
   int scr;
@@ -401,7 +408,9 @@ private:
       XA_XDNDAWARE,
       XA_MULTIPLE,
       XA_TEXT_URI_LIST,
-      XA_TEXT_PLAIN;
+      XA_TEXT_PLAIN,
+      XA_NET_WM_ICON,
+      XA_CARDINAL_ATOM;
 
   int m_argc;
   char **m_argv;
@@ -637,6 +646,9 @@ private:
     int m_user_color_instance;
 
     unsigned int m_modifier_pressed = 0;
+
+    const unsigned long *m_net_wm_icon_data = NULL;
+    size_t m_net_wm_icon_data_length = 0;
 };
 
 #endif
