@@ -196,46 +196,124 @@ int AGUIXFont::getBaseline() const
 #endif
 }
 
+#ifndef HAVE_XFT
 int AGUIXFont::textWidth( const char *str, int count ) const
 {
-  int w = 0;
+    int w = 0;
+
+#  ifndef DISABLE_UTF8_SUPPORT
+    if ( _fontset == NULL ) {
+#  endif
+        w = XTextWidth( font, str, count );
+#  ifndef DISABLE_UTF8_SUPPORT
+    } else {
+        w = XmbTextEscapement( _fontset, str, count );
+    }
+#  endif
+  
+    return w;
+}
+#endif
+
+#define INITIAL_CHUNK_LENGTH 120
 
 #ifdef HAVE_XFT
-  XGlyphInfo extents;
-  //TODO extents overflows if str is too long
-  //     is there a better way of asking for the string width?
+int AGUIXFont::textWidth( const char *str, int count ) const
+{
+    int w = 0;
+
+    XGlyphInfo extents;
+
+    // since extents overflows if str is too long. But splitting UTF8
+    // strings might not be correct for all characters so try to find
+    // the largest chunk we can use without splitting. Use a simple
+    // dynamic limit. Try to increase as far as possible until it
+    // overflows and then reduce the limit each time it overflows. It
+    // will take quite a lot of steps but is simple and once it has a
+    // stable limit the speed will be ok.
+    //
+    // It would be faster to use a binary search for best performance
+    // but it will make it more complicated too as very long strings
+    // might overflow without notice (overflowing multiple times into
+    // a positive value). And it is ok right now since the adjustment
+    // is only done once.
+
+    static int chunk_limit = INITIAL_CHUNK_LENGTH;
+    static int max_chunk_limit = 0;
+
+    for (;;) {
+        if ( max_chunk_limit == 0 && count > chunk_limit ) {
+            chunk_limit++;
+        }
+
 #  ifndef DISABLE_UTF8_SUPPORT
-  if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
-    XftTextExtentsUtf8( aguix->getDisplay(),
-                        _xftfont,
-                        (XftChar8*)str,
-                        count,
-                        &extents );
-  } else {
+        if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+            if ( count > chunk_limit ) {
+                int new_pos = count / 2;
+
+                new_pos = UTF8::movePosBackToValidPos( str, new_pos );
+
+                if ( new_pos <= 0 || new_pos >= count ) {
+                    // not supposed to happen
+                    return 0;
+                }
+
+                int w1 = textWidth( str, new_pos );
+                int w2 = textWidth( str + new_pos, count - new_pos );
+
+                if ( w1 < 0 || w2 < 0 ) {
+                    // there is an overflow so reduce limit and try again.
+                    chunk_limit--;
+                    max_chunk_limit = chunk_limit;
+
+                    continue;
+                }
+
+                return w1 + w2;
+            } else {
+                XftTextExtentsUtf8( aguix->getDisplay(),
+                                    _xftfont,
+                                    (XftChar8*)str,
+                                    count,
+                                    &extents );
+                //printf("BOO4:%d\n",extents.xOff);
+                break;
+            }
+        } else {
 #  endif
-    XftTextExtents8( aguix->getDisplay(),
-                     _xftfont,
-                     (XftChar8*)str,
-                     count,
-                     &extents );
+            if ( count > chunk_limit ) {
+                int new_pos = count / 2;
+
+                int w1 = textWidth( str, new_pos );
+                int w2 = textWidth( str + new_pos, count - new_pos );
+
+                if ( w1 < 0 || w2 < 0 ) {
+                    // there is an overflow so reduce limit and try again.
+                    chunk_limit--;
+                    max_chunk_limit = chunk_limit;
+
+                    continue;
+                }
+
+                return w1 + w2;
+            } else {
+                XftTextExtents8( aguix->getDisplay(),
+                                 _xftfont,
+                                 (XftChar8*)str,
+                                 count,
+                                 &extents );
+                break;
+            }
 #  ifndef DISABLE_UTF8_SUPPORT
-  }
+        }
 #  endif
-  w = extents.xOff;
-#else
-#  ifndef DISABLE_UTF8_SUPPORT
-  if ( _fontset == NULL ) {
-#  endif
-    w = XTextWidth( font, str, count );
-#  ifndef DISABLE_UTF8_SUPPORT
-  } else {
-    w = XmbTextEscapement( _fontset, str, count );
-  }
-#  endif
-#endif
+    }
+
+    w = extents.xOff;
   
-  return w;
+    return w;
 }
+#endif
 
 void AGUIXFont::drawText( DrawableCont &dc, const char *text, int x, int y, const AGUIXColor &color )
 {
