@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2017 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -1120,6 +1120,8 @@ void AWindow::doCreateStuff()
       }
   }
 
+  applyIcon();
+
   // clear window
   XClearWindow( dsp, win );
 
@@ -1621,3 +1623,19 @@ Widget *AWindow::findWidgetForRootPos( int rx, int ry )
 
     return w;
 }
+
+void AWindow::applyIcon()
+{
+    const unsigned long *data = NULL;
+    size_t data_length = 0;
+
+    if ( ! _aguix->getStandardIconData( &data, &data_length ) ) {
+        return;
+    }
+
+    XChangeProperty( _aguix->getDisplay(),
+                     win,
+                     _aguix->getAtom( AGUIX::NET_WM_ICON_ATOM ),
+                     _aguix->getAtom( AGUIX::CARDINAL_ATOM ),
+                     32, PropModeReplace, (const unsigned char*)data, data_length );
+}
