@@ -1,6 +1,6 @@
 /* basic_actions.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,9 +27,9 @@
 #include "nmspecialsourceext.hh"
 #include "worker_locale.h"
 #include "dnd.h"
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/awindow.h>
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/awindow.h"
 #include "wconfig.h"
 #include "datei.h"
 #include "virtualdirmode.hh"
@@ -160,9 +160,9 @@ void DNDAction::normalmodedndaction( ActionMessage *am )
   }
 }
 
-List *DNDAction::DNDActionDescr::get_action_list( WCFiletype *ft ) const
+command_list_t DNDAction::DNDActionDescr::get_action_list( WCFiletype *ft ) const
 {
-    if ( ft == NULL ) return NULL;
+    if ( ft == NULL ) return {};
     return ft->getDNDActions();
 }
 
@@ -319,9 +319,9 @@ void DoubleClickAction::normalmodeddaction( ActionMessage *am )
   }
 }
 
-List *DoubleClickAction::DoubleClickActionDescr::get_action_list( WCFiletype *ft ) const
+command_list_t DoubleClickAction::DoubleClickActionDescr::get_action_list( WCFiletype *ft ) const
 {
-    if ( ft == NULL ) return NULL;
+    if ( ft == NULL ) return {};
     return ft->getDoubleClickActions();
 }
 
@@ -478,9 +478,9 @@ void ShowAction::normalmodeshow( ActionMessage *am )
   }
 }
 
-List *ShowAction::ShowActionDescr::get_action_list( WCFiletype *ft ) const
+command_list_t ShowAction::ShowActionDescr::get_action_list( WCFiletype *ft ) const
 {
-    if ( ft == NULL ) return NULL;
+    if ( ft == NULL ) return {};
     return ft->getShowActions();
 }
 
@@ -637,9 +637,9 @@ void RawShowAction::normalmoderawshow( ActionMessage *am )
   }
 }
 
-List *RawShowAction::RawShowActionDescr::get_action_list( WCFiletype *ft ) const
+command_list_t RawShowAction::RawShowActionDescr::get_action_list( WCFiletype *ft ) const
 {
-    if ( ft == NULL ) return NULL;
+    if ( ft == NULL ) return {};
     return ft->getRawShowActions();
 }
 
@@ -902,9 +902,9 @@ UserAction::UserActionDescr::UserActionDescr( int id ) : m_id( id )
 {
 }
 
-List *UserAction::UserActionDescr::get_action_list( WCFiletype *ft ) const
+command_list_t UserAction::UserActionDescr::get_action_list( WCFiletype *ft ) const
 {
-    if ( ft == NULL ) return NULL;
+    if ( ft == NULL ) return {};
     return ft->getUserActions( m_id );
 }
 
