@@ -22,16 +22,16 @@
 #include "changecolumnsop.hh"
 #include "listermode.h"
 #include "worker.h"
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/solidbutton.h>
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/slider.h>
-#include <aguix/choosebutton.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/acontainerbb.h>
-#include <aguix/textview.h>
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/solidbutton.h"
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/slider.h"
+#include "aguix/choosebutton.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/acontainerbb.h"
+#include "aguix/textview.h"
 #include <sstream>
 #include <algorithm>
 #include "datei.h"
