@@ -24,8 +24,8 @@
 #include "worker.h"
 #include "nmspecialsourceext.hh"
 #include "datei.h"
-#include <aguix/button.h>
-#include <aguix/choosebutton.h>
+#include "aguix/button.h"
+#include "aguix/choosebutton.h"
 #include "worker_locale.h"
 #include "chmodorder.hh"
 #include "virtualdirmode.hh"
