@@ -25,16 +25,16 @@
 #include "chmodorder.hh"
 #include "chownorder.hh"
 #include "verzeichnis.hh"
-#include <aguix/lowlevelfunc.h>
-#include <aguix/util.h>
+#include "aguix/lowlevelfunc.h"
+#include "aguix/util.h"
 #include "worker.h"
-#include <aguix/request.h>
-#include <aguix/choosebutton.h>
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/awindow.h>
-#include <aguix/acontainer.h>
-#include <aguix/fieldlistview.h>
+#include "aguix/request.h"
+#include "aguix/choosebutton.h"
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/awindow.h"
+#include "aguix/acontainer.h"
+#include "aguix/fieldlistview.h"
 #include "simplelist.hh"
 
 ChModOwnCore::ChModOwnCore( struct NM_chmodorder *chmodorder,
