@@ -24,16 +24,16 @@
 #include "nmcopyopdir.hh"
 #include "chtimeorder.hh"
 #include "verzeichnis.hh"
-#include <aguix/lowlevelfunc.h>
-#include <aguix/util.h>
+#include "aguix/lowlevelfunc.h"
+#include "aguix/util.h"
 #include "worker.h"
-#include <aguix/request.h>
-#include <aguix/stringgadget.h>
-#include <aguix/button.h>
-#include <aguix/choosebutton.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/awindow.h>
-#include <aguix/acontainer.h>
+#include "aguix/request.h"
+#include "aguix/stringgadget.h"
+#include "aguix/button.h"
+#include "aguix/choosebutton.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/awindow.h"
+#include "aguix/acontainer.h"
 #include "calendar.hh"
 
 ChTimeCore::ChTimeCore( struct chtimeorder *chtimeorder,
