@@ -451,7 +451,8 @@ struct mytoken tokenlist[]={
   { TERMINAL_RETURNS_EARLY_WCP, "terminalreturnsearly" },
   { DIRECTORYPRESETS_WCP, "directorypresets" },
   { DIRECTORYPRESET_WCP, "directorypreset" },
-  { HELPOP_WCP, "helpop" }
+  { HELPOP_WCP, "helpop" },
+  { PRIORITY_WCP, "priority" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
