@@ -27,8 +27,8 @@
 #include "copyorder.hh"
 #include "simplelist.hh"
 #include "verzeichnis.hh"
-#include <aguix/lowlevelfunc.h>
-#include <aguix/util.h>
+#include "aguix/lowlevelfunc.h"
+#include "aguix/util.h"
 #include <chrono>
 #include <ratio>
 #include "nwc_path.hh"
@@ -829,9 +829,10 @@ CopyCore::copydir( const FileEntry *fe, NM_CopyOp_Dir *cod, bool acceptrename, c
                             // fe is a dir so if it is a link it is not corrupt
                             mode_t m = ( fe->isLink == true ) ? fe->dmode() : fe->mode();
                             m = getModeWithEnsureOption( m, *m_copyorder );
-                                
-                            worker_chown( destsubdir, ( fe->isLink == true ) ? fe->duserid() : fe->userid(),
-                                          ( fe->isLink == true ) ? fe->dgroupid() : fe->groupid() );
+
+                            int res = worker_chown( destsubdir, ( fe->isLink == true ) ? fe->duserid() : fe->userid(),
+                                                    ( fe->isLink == true ) ? fe->dgroupid() : fe->groupid() );
+                            (void)res; // ignore result for now
                             worker_chmod( destsubdir, m );
                             utb.actime = ( fe->isLink == true ) ? fe->dlastaccess() : fe->lastaccess();
                             utb.modtime = ( fe->isLink == true ) ? fe->dlastmod() : fe->lastmod();
