@@ -27,9 +27,9 @@
 #include "worker_locale.h"
 #include "datei.h"
 #include "dnd.h"
-#include <aguix/choosebutton.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/button.h>
+#include "aguix/choosebutton.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/button.h"
 #include "copyorder.hh"
 #include "virtualdirmode.hh"
 
