@@ -26,8 +26,8 @@
 #include "datei.h"
 #include "dnd.h"
 #include "worker_locale.h"
-#include <aguix/button.h>
-#include <aguix/choosebutton.h>
+#include "aguix/button.h"
+#include "aguix/choosebutton.h"
 #include "createsymlinkorder.hh"
 #include "virtualdirmode.hh"
 
