@@ -1,6 +1,6 @@
 /* datei.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -20,11 +20,11 @@
  */
 
 #include "datei.h"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 #include "wconfig.h"
 #include "grouphash.h"
-#include <aguix/mutex.h>
-#include <aguix/utf8.hh>
+#include "aguix/mutex.h"
+#include "aguix/utf8.hh"
 #include "nwc_os.hh"
 #include "nwc_path.hh"
 #include "worker.h"
@@ -498,37 +498,40 @@ char *Datei::getNameWithoutExt(const char *name)
  * retries no tmp file couldn't be created
  * THREADSAFE
  */
-char *Datei::createTMPName( const char *infix )
+char *Datei::createTMPName( const char *infix,
+                            const char *suffix )
 {
-  char *returnstr = NULL, buffer[ 2 * A_BYTESFORNUMBER( int ) ];
-  int rannr;
-  static int lfdnr = 0;
-  int tfd;
-  static MutEx lock;
+    char *returnstr = NULL, buffer[ 2 * A_BYTESFORNUMBER( int ) ];
+    int rannr;
+    static int lfdnr = 0;
+    int tfd;
+    static MutEx lock;
   
-  if ( infix == NULL ) infix = "";
+    if ( infix == NULL ) infix = "";
+    if ( suffix == NULL ) suffix = "";
   
-  lock.lock();
-  for( int retry = 0; retry < 1000; retry++ ) {
-    rannr=rand();
-    sprintf( buffer, "%d%d", lfdnr++, rannr );
-    returnstr = (char*)_allocsafe( strlen( worker_tmpdir() ) + 
-				   strlen( "/worker" ) +
-                                   strlen( infix ) + strlen( buffer ) + 1 );
-    sprintf( returnstr, "%s/worker%s%s", worker_tmpdir(), infix, buffer );
-    if(Datei::lfileExistsExt(returnstr)==Datei::D_FE_NOFILE) {
-      tfd = ::worker_open( returnstr, O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR );
-      if ( tfd >= 0 ) {
-	::worker_close( tfd );
-	worker_chmod( returnstr, S_IRUSR | S_IWUSR );
-	break;
-      }
+    lock.lock();
+    for( int retry = 0; retry < 1000; retry++ ) {
+        rannr=rand();
+        sprintf( buffer, "%d%d", lfdnr++, rannr );
+        returnstr = (char*)_allocsafe( strlen( worker_tmpdir() ) + 
+                                       strlen( "/worker" ) +
+                                       strlen( infix ) + strlen( buffer ) +
+                                       strlen( suffix ) + 1 );
+        sprintf( returnstr, "%s/worker%s%s%s", worker_tmpdir(), infix, buffer, suffix );
+        if(Datei::lfileExistsExt(returnstr)==Datei::D_FE_NOFILE) {
+            tfd = ::worker_open( returnstr, O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR );
+            if ( tfd >= 0 ) {
+                ::worker_close( tfd );
+                worker_chmod( returnstr, S_IRUSR | S_IWUSR );
+                break;
+            }
+        }
+        _freesafe(returnstr);
+        returnstr = NULL;
     }
-    _freesafe(returnstr);
-    returnstr = NULL;
-  }
-  lock.unlock();
-  return returnstr;
+    lock.unlock();
+    return returnstr;
 }
 
 std::string Datei::createTMPHardlink( const std::string &name )
@@ -1309,12 +1312,12 @@ void Datei::configCloseSection()
   putLine( str1.c_str() );
 }
 
-size_t Datei::read( char *buffer, size_t len )
+ssize_t Datei::read( char *buffer, size_t len )
 {
     if ( buffer == NULL || len < 1 ) return 0;
     if ( fd < 0 ) return 0;
 
-    size_t count;
+    ssize_t count;
   
     count = ::worker_read( fd, buffer, len );
     
