@@ -1,6 +1,6 @@
 /* datei.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -81,7 +81,8 @@ public:
   static d_fe_t lfileExistsExt(const char*);
   static char *getFilenameFromPath(const char*);
   static char *getNameWithoutExt(const char*);
-  static char *createTMPName( const char *infix = NULL );
+    static char *createTMPName( const char *infix = NULL,
+                                const char *suffix = NULL );
   static std::string createTMPHardlink( const std::string &name );
   static char *shrinkFilename( const char *str, int maxlength, AWidth &lencalc );
   static loff_t fileSize( const char * );
@@ -108,7 +109,7 @@ public:
   void configOpenSection( const char *sectioname );
   void configCloseSection();
 
-  size_t read( char *buffer, size_t len );
+  ssize_t read( char *buffer, size_t len );
 private:
   int fd;
   long error;
