@@ -24,9 +24,9 @@
 #include "deleteop.h"
 #include "nmspecialsourceext.hh"
 #include "worker_locale.h"
-#include <aguix/button.h>
-#include <aguix/choosebutton.h>
-#include <aguix/solidbutton.h>
+#include "aguix/button.h"
+#include "aguix/choosebutton.h"
+#include "aguix/solidbutton.h"
 #include "datei.h"
 #include "deleteorder.hh"
 #include "virtualdirmode.hh"
