@@ -24,7 +24,7 @@
 
 #include "wdefines.h"
 #include "functionproto.h"
-#include <aguix/request.h>
+#include "aguix/request.h"
 
 class AGUIX;
 class AWindow;
