@@ -20,12 +20,12 @@
  */
 
 #include "dirbookmarkui.hh"
-#include <aguix/aguix.h>
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
-#include <aguix/solidbutton.h>
+#include "aguix/aguix.h"
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
+#include "aguix/solidbutton.h"
 #include "worker_locale.h"
 #include "bookmarkdbentry.hh"
 #include "bookmarkdbfilter.hh"
