@@ -1,6 +1,6 @@
 /* dircompareop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2017 Ralf Hoffmann.
+ * Copyright (C) 2017-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,12 +22,12 @@
 #include "dircompareop.hh"
 #include "listermode.h"
 #include "worker.h"
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/acontainerbb.h>
-#include <aguix/textview.h>
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/acontainerbb.h"
+#include "aguix/textview.h"
 #include "datei.h"
 #include "worker_locale.h"
 #include "virtualdirmode.hh"
@@ -35,6 +35,7 @@
 #include "dircomparewin.hh"
 #include "nwc_path.hh"
 #include "commonprefix.hh"
+#include "aguix/stringgadget.h"
 
 int DirCompareOp::s_vdir_number = 1;
 
@@ -86,15 +87,29 @@ int DirCompareOp::compareFile( NWC::FSEntry *my_entry,
 
     int res = 0;
 
-    size_t my_read;
-    size_t other_read;
+    ssize_t my_read;
+    ssize_t other_read;
 
     size_t total_bytes = my_entry->stat_size();
     size_t total_bytes_read = 0;
 
     for (;;) {
-        my_read = my_fh.read( my_buf, 128 * 1024 );
-        other_read = other_fh.read( other_buf, 128 * 1024 );
+        size_t bufsize = 128 * 1024;
+
+        if ( m_file_size_limit > 0 && (loff_t)total_bytes_read <= m_file_size_limit ) {
+            loff_t remaining = m_file_size_limit - total_bytes_read;
+
+            if ( remaining == 0 ) {
+                break;
+            }
+
+            if ( remaining < (loff_t)bufsize ) {
+                bufsize = remaining;
+            }
+        }
+
+        my_read = my_fh.read( my_buf, bufsize );
+        other_read = other_fh.read( other_buf, bufsize );
 
         if ( my_read != other_read ) {
             res = 1;
@@ -137,7 +152,8 @@ int DirCompareOp::compareFile( NWC::FSEntry *my_entry,
 int DirCompareOp::compareEntry( NWC::FSEntry *my_entry,
                                 NWC::FSEntry *other_entry,
                                 std::unique_ptr< NWC::Dir > &my_res_vdir,
-                                std::unique_ptr< NWC::Dir > &other_res_vdir )
+                                std::unique_ptr< NWC::Dir > &other_res_vdir,
+                                enum compare_key cmp_key )
 {
     NWC::Dir *my_dir = dynamic_cast< NWC::Dir * >( my_entry );
     NWC::Dir *other_dir = dynamic_cast< NWC::Dir * >( other_entry );
@@ -162,7 +178,7 @@ int DirCompareOp::compareEntry( NWC::FSEntry *my_entry,
 
         m_progress_win->setCurrentDir( "" );
 
-        if ( m_compare_mode != COMPARE_SIZE_AND_MDATE ) return res;
+        if ( m_compare_mode != COMPARE_FILENAME_FILESIZE_MDATE ) return res;
 
         if ( res != 0 ) return res;
 
@@ -178,6 +194,12 @@ int DirCompareOp::compareEntry( NWC::FSEntry *my_entry,
 
     // both are not dirs so try to compare
 
+    if ( cmp_key == FILESIZE ) {
+        return 0;
+    } else if ( cmp_key == FILESIZE_CHECKSUM ) {
+        return 0;
+    }
+
     if ( ( my_entry->stat_mode() & S_IFMT ) != ( other_entry->stat_mode() & S_IFMT ) ) {
         return 1;
     }
@@ -206,9 +228,9 @@ int DirCompareOp::compareEntry( NWC::FSEntry *my_entry,
         return 1;
     }
 
-    if ( m_compare_mode == COMPARE_CONTENT ) {
+    if ( m_compare_mode == COMPARE_FILENAME_CONTENT ) {
         return compareFile( my_entry, other_entry );
-    } else if ( m_compare_mode == COMPARE_SIZE_AND_MDATE ) {
+    } else if ( m_compare_mode == COMPARE_FILENAME_FILESIZE_MDATE ) {
         if ( my_entry->stat_lastmod() != other_entry->stat_lastmod() ) {
             return 1;
         }
@@ -217,6 +239,108 @@ int DirCompareOp::compareEntry( NWC::FSEntry *my_entry,
     return 0;
 }
 
+
+int DirCompareOp::key_compare( const compare_element &lhs,
+                               const compare_element &rhs,
+                               enum compare_key key )
+{
+    if ( key == FILESIZE ) {
+        return rhs.entry->stat_size() - lhs.entry->stat_size();
+    } else if ( key == FILESIZE_CHECKSUM ) {
+        if ( lhs.entry->stat_size() < rhs.entry->stat_size() ) {
+            return -1;
+        } else if ( lhs.entry->stat_size() > rhs.entry->stat_size() ) {
+            return 1;
+        } else {
+#ifdef HAVE_OPENSSL_SHA256
+            return memcmp( &lhs.chksum, &rhs.chksum, sizeof( lhs.chksum ) );
+#else
+            return 0;
+#endif
+        }
+    } else {
+        return StringComparator::compare( lhs.basename,
+                                          rhs.basename );
+    }
+}
+
+void DirCompareOp::calc_checksum( compare_element &element ) const
+{
+    if ( ! element.entry->isReg() ) {
+        return;
+    }
+
+#ifdef HAVE_OPENSSL_SHA256
+    SHA256_CTX c;
+
+    int res = SHA256_Init( &c );
+
+    if ( res != 1 ) {
+        fprintf( stderr, "Failed to init checksum\n" );
+        return;
+    }
+
+    Datei fh;
+
+    if ( fh.open( element.entry->getFullname().c_str(),
+                  "r" ) != 0 ) {
+        return;
+    }
+
+    char buf[128 * 1024];
+
+    size_t total_bytes_read = 0;
+    size_t total_bytes = element.entry->stat_size();
+
+    for (;;) {
+        size_t bufsize = sizeof( buf );
+
+        if ( m_file_size_limit > 0 && (loff_t)total_bytes_read <= m_file_size_limit ) {
+            loff_t remaining = m_file_size_limit - total_bytes_read;
+
+            if ( remaining == 0 ) {
+                break;
+            }
+
+            if ( remaining < (loff_t)bufsize ) {
+                bufsize = remaining;
+            }
+        }
+
+        ssize_t bytes_read = fh.read( buf, bufsize );
+
+        if ( bytes_read < 0 ) {
+            break;
+        }
+
+        if ( bytes_read == 0 ) {
+            break;
+        }
+
+        res = SHA256_Update( &c,
+                             buf, bytes_read );
+        if ( res != 1 ) {
+            fprintf( stderr, "Failed to update checksum\n" );
+        }
+
+        total_bytes_read += bytes_read;
+
+        if ( total_bytes > 0 ) {
+            m_progress_win->setEntryPercent( total_bytes_read * 100 / total_bytes );
+        }
+
+        if ( m_progress_win->check() ) {
+            break;
+        }
+    }
+
+    res = SHA256_Final( &element.chksum[0], &c );
+    if ( res != 1 ) {
+        fprintf( stderr, "Failed to get checksum\n" );
+    }
+#endif
+}
+
 int DirCompareOp::compareDirs( std::shared_ptr< NWC::Dir > my_dir,
                                std::shared_ptr< NWC::Dir > other_dir,
                                std::vector< bool > *my_equal,
@@ -224,19 +348,8 @@ int DirCompareOp::compareDirs( std::shared_ptr< NWC::Dir > my_dir,
                                std::unique_ptr< NWC::Dir > &my_res_vdir,
                                std::unique_ptr< NWC::Dir > &other_res_vdir )
 {
-    my_dir->sort( []( const NWC::FSEntry &lhs,
-                      const NWC::FSEntry &rhs ) {
-                      return StringComparator::compare( lhs.getFullname(),
-                                                        rhs.getFullname() ) < 0;
-                  } );
-    other_dir->sort( []( const NWC::FSEntry &lhs,
-                         const NWC::FSEntry &rhs ) {
-                         return StringComparator::compare( lhs.getFullname(),
-                                                           rhs.getFullname() ) < 0;
-                     } );
-
-    int my_pos = 0;
-    int other_pos = 0;
+    size_t my_pos = 0;
+    size_t other_pos = 0;
     int unequal_count = 0;
 
     if ( my_equal ) {
@@ -279,111 +392,175 @@ int DirCompareOp::compareDirs( std::shared_ptr< NWC::Dir > my_dir,
         other_common_prefix = cp.getCommonPrefix();
     }
 
+    std::vector< compare_element > my_dir_elements;
+    std::vector< compare_element > other_dir_elements;
+
+    for ( my_pos = 0; my_pos < my_dir->size(); my_pos++ ) {
+        compare_element ce( my_dir->getEntryAtPos( my_pos ),
+                            my_pos );
+        if ( my_is_virtual ) {
+            ce.basename = NWC::Path::get_extended_basename( my_common_prefix,
+                                                            ce.entry->getFullname() );
+        } else {
+            ce.basename = ce.entry->getBasename();
+        }
+        my_dir_elements.push_back( ce );
+    }
+    for ( other_pos = 0; other_pos < other_dir->size(); other_pos++ ) {
+        compare_element ce( other_dir->getEntryAtPos( other_pos ),
+                            other_pos );
+        if ( other_is_virtual ) {
+            ce.basename = NWC::Path::get_extended_basename( other_common_prefix,
+                                                            ce.entry->getFullname() );
+        } else {
+            ce.basename = ce.entry->getBasename();
+        }
+        other_dir_elements.push_back( ce );
+    }
+
+    enum compare_key cmp_key;
+
+    switch ( m_compare_mode ) {
+        case COMPARE_FILESIZE:
+            cmp_key = FILESIZE;
+            break;
+        case COMPARE_CHECKSUM:
+            cmp_key = FILESIZE_CHECKSUM;
+            break;
+        default:
+            cmp_key = FILENAME;
+    }
+
+    if ( m_compare_mode == COMPARE_CHECKSUM ) {
+        for ( auto &e : my_dir_elements ) {
+            calc_checksum( e );
+        }
+        for ( auto &e : other_dir_elements ) {
+            calc_checksum( e );
+        }
+    }
+
+    std::sort( my_dir_elements.begin(),
+               my_dir_elements.end(),
+               [cmp_key]( auto &lhs, auto &rhs ) {
+                   return key_compare(lhs, rhs, cmp_key) < 0;
+               });
+    std::sort( other_dir_elements.begin(),
+               other_dir_elements.end(),
+               [cmp_key]( auto &lhs, auto &rhs ) {
+                   return key_compare(lhs, rhs, cmp_key) < 0;
+               });
+
     other_pos = 0;
 
-    for ( my_pos = 0; my_pos < my_dir->size() && m_stop == false; my_pos++ ) {
-        std::string my_basename;
-        std::string other_basename;
-
-        if ( my_is_virtual ) {
-            my_basename = NWC::Path::get_extended_basename( my_common_prefix,
-                                                            my_dir->getEntryAtPos( my_pos )->getFullname() );
-        } else {
-            my_basename = my_dir->getEntryAtPos( my_pos )->getBasename();
-        }
-
-        if ( other_pos < other_dir->size() ) {
-            if ( other_is_virtual ) {
-                other_basename = NWC::Path::get_extended_basename( other_common_prefix,
-                                                                   other_dir->getEntryAtPos( other_pos )->getFullname() );
-            } else {
-                other_basename = other_dir->getEntryAtPos( other_pos )->getBasename();
-            }
-        }
-        
-        while ( other_pos < other_dir->size() &&
-                StringComparator::compare( my_basename,
-                                           other_basename ) > 0 ) {
+    for ( my_pos = 0; my_pos < my_dir_elements.size() && m_stop == false; ) {
+        while ( other_pos < other_dir_elements.size() &&
+                key_compare( my_dir_elements[my_pos], other_dir_elements[other_pos], cmp_key ) > 0 ) {
             if ( other_equal ) {
-                other_equal->at( other_pos ) = false;
+                other_equal->at( other_dir_elements[other_pos].orig_pos ) = false;
             }
             if ( other_res_vdir ) {
-                other_res_vdir->add( *other_dir->getEntryAtPos( other_pos ) );
+                other_res_vdir->add( *other_dir_elements[other_pos].entry );
             }
             other_pos++;
             unequal_count++;
 
             m_progress_win->finishedEntry();
-
-            if ( other_pos < other_dir->size() ) {
-                if ( other_is_virtual ) {
-                    other_basename = NWC::Path::get_extended_basename( other_common_prefix,
-                                                                        other_dir->getEntryAtPos( other_pos )->getFullname() );
-                } else {
-                    other_basename = other_dir->getEntryAtPos( other_pos )->getBasename();
-                }
-            }
         };
 
         if ( other_pos >= other_dir->size() ) {
             // unequal since there is no corresponding element in the other dir
             if ( my_equal ) {
-                my_equal->at( my_pos ) = false;
+                my_equal->at( my_dir_elements[my_pos].orig_pos ) = false;
             }
             unequal_count++;
+
+            my_pos++;
+            m_progress_win->finishedEntry();
         } else {
-            if ( my_basename == other_basename ) {
-                // it's the same entry so check for compare mode
-                if ( compareEntry( my_dir->getEntryAtPos( my_pos ),
-                                   other_dir->getEntryAtPos( other_pos ),
-                                   my_res_vdir,
-                                   other_res_vdir ) == 0 ) {
-                    if ( my_equal ) {
-                        my_equal->at( my_pos ) = true;
-                    }
-                    if ( other_equal ) {
-                        other_equal->at( other_pos ) = true;
-                    }
-                    if ( my_res_vdir ) {
-                        my_res_vdir->add( *my_dir->getEntryAtPos( my_pos ) );
-                    }
-                } else {
-                    if ( my_equal ) {
-                        my_equal->at( my_pos ) = false;
-                    }
-                    if ( other_equal ) {
-                        other_equal->at( other_pos ) = false;
-                    }
-                    if ( other_res_vdir ) {
-                        other_res_vdir->add( *other_dir->getEntryAtPos( other_pos ) );
-                    }
+            if ( key_compare( my_dir_elements[my_pos],
+                              other_dir_elements[other_pos], cmp_key ) == 0 ) {
+                size_t my_start_pos = my_pos;
+                size_t my_end_pos = my_pos + 1;
+
+                for ( ; my_end_pos < my_dir_elements.size() &&
+                          key_compare( my_dir_elements[my_start_pos],
+                                       my_dir_elements[my_end_pos], cmp_key ) == 0; my_end_pos++ ) {
                 }
 
-                other_pos++;
+                size_t other_start_pos = other_pos;
+                size_t other_end_pos = other_pos + 1;
+                
+                for ( ; other_end_pos < other_dir_elements.size() &&
+                          key_compare( other_dir_elements[other_start_pos],
+                                       other_dir_elements[other_end_pos], cmp_key ) == 0; other_end_pos++ ) {
+                }
 
-                m_progress_win->finishedEntry();
+                for ( size_t my_block_pos = my_start_pos; my_block_pos < my_end_pos; my_block_pos++ ) {
+                    for ( size_t other_block_pos = other_start_pos; other_block_pos < other_end_pos; other_block_pos++ ) {
+                        bool cmp_res = false;
+
+                        // it's the same entry so check for compare mode
+                        if ( compareEntry( my_dir_elements[my_block_pos].entry,
+                                           other_dir_elements[other_block_pos].entry,
+                                           my_res_vdir,
+                                           other_res_vdir,
+                                           cmp_key ) == 0 ) {
+                            cmp_res = true;
+                        }
+
+                        if ( my_equal ) {
+                            my_equal->at( my_dir_elements[my_block_pos].orig_pos ) = cmp_res;
+                        }
+                        if ( other_equal && cmp_res == true) {
+                            other_equal->at( other_dir_elements[other_block_pos].orig_pos ) = cmp_res;
+                        }
+
+                        if ( cmp_res ) {
+                            if ( my_res_vdir ) {
+                                my_res_vdir->add( *my_dir_elements[my_block_pos].entry );
+                            }
+                        }
+                    }
+                    m_progress_win->finishedEntry();
+                }
+
+                // if any of the other elements of same key are
+                // "equal", put them in the virtual dir
+                for ( size_t other_block_pos = other_start_pos; other_block_pos < other_end_pos; other_block_pos++ ) {
+                    if ( other_equal->at( other_dir_elements[other_block_pos].orig_pos ) == false ) {
+                        if ( other_res_vdir ) {
+                            other_res_vdir->add( *other_dir_elements[other_block_pos].entry );
+                        }
+                    }
+                    m_progress_win->finishedEntry();
+                }
+
+                my_pos = my_end_pos;
+                other_pos = other_end_pos;
             } else {
                 // the next element in other dir is of a larger name so it's unequal
                 if ( my_equal ) {
-                    my_equal->at( my_pos ) = false;
+                    my_equal->at( my_dir_elements[my_pos].orig_pos ) = false;
                 }
                 unequal_count++;
+
+                my_pos++;
+                m_progress_win->finishedEntry();
             }
         }
 
-        m_progress_win->finishedEntry();
-
         if ( m_progress_win->check() ) {
             m_stop = true;
         }
     }
 
-    for ( ; other_pos < other_dir->size() && m_stop == false; other_pos++ ) {
+    for ( ; other_pos < other_dir_elements.size() && m_stop == false; other_pos++ ) {
         if ( other_equal ) {
-            other_equal->at( other_pos ) = false;
+            other_equal->at( other_dir_elements[other_pos].orig_pos ) = false;
         }
         if ( other_res_vdir ) {
-            other_res_vdir->add( *other_dir->getEntryAtPos( other_pos ) );
+            other_res_vdir->add( *other_dir_elements[other_pos].entry );
         }
         unequal_count++;
 
@@ -429,8 +606,10 @@ DirCompareOp::run( WPUContext *wpu, ActionMessage *msg )
         }
     }
 
+    const bool slow_compare = m_compare_mode == COMPARE_FILENAME_CONTENT || m_compare_mode == COMPARE_CHECKSUM;
+
     m_progress_win = new DirCompareWin( Worker::getAGUIX(),
-                                        m_compare_mode == COMPARE_CONTENT );
+                                        slow_compare );
     m_progress_win->open();
 
     m_stop = false;
@@ -481,12 +660,12 @@ DirCompareOp::run( WPUContext *wpu, ActionMessage *msg )
                     this_vdm->showDir( this_res_dir );
                     other_vdm->showDir( other_res_dir );
                 } else {
-                    for ( int this_pos = 0; this_pos < this_sdir->size(); this_pos++ ) {
+                    for ( size_t this_pos = 0; this_pos < this_sdir->size(); this_pos++ ) {
                         this_vdm->setEntrySelectionState( this_sdir->getEntryAtPos( this_pos )->getFullname(),
                                                           this_equal.at( this_pos ) );
                     }
 
-                    for ( int other_pos = 0; other_pos < other_sdir->size(); other_pos++ ) {
+                    for ( size_t other_pos = 0; other_pos < other_sdir->size(); other_pos++ ) {
                         other_vdm->setEntrySelectionState( other_sdir->getEntryAtPos( other_pos )->getFullname(),
                                                            ! other_equal.at( other_pos ) );
                     }
@@ -520,7 +699,7 @@ DirCompareOp::doConfigure()
     AWindow *win = new AWindow( aguix, 10, 10, 10, 10, title.c_str(), AWindow::AWINDOW_DIALOG );
     win->create();
     
-    AContainer *ac0 = win->setContainer( new AContainer( win, 1, 4 ), true );
+    AContainer *ac0 = win->setContainer( new AContainer( win, 1, 5 ), true );
     ac0->setMinSpace( 5 );
     ac0->setMaxSpace( 5 );
     ac0->setBorderWidth( 5 );
@@ -529,10 +708,10 @@ DirCompareOp::doConfigure()
     TextStorageString help_ts( catalog.getLocale( 1180 ), lencalc );
     TextView *help_tv = (TextView*)ac0->add( new TextView( aguix,
                                                            0, 0, 400, 50, "", help_ts ),
-                                             0, 0, AContainer::CO_INCW );
+                                             0, 0, AContainer::CO_MIN );
     help_tv->setLineWrap( true );
     help_tv->showFrame( false );
-    help_tv->maximizeYLines( 10, help_tv->getWidth() );
+    help_tv->maximizeYLines( 15, help_tv->getWidth() );
     ac0->readLimits();
     help_tv->show();
     help_tv->setAcceptFocus( false );
@@ -546,13 +725,16 @@ DirCompareOp::doConfigure()
     ac1_1->setMinSpace( 5 );
     ac1_1->setMaxSpace( 5 );
     ac1_1->setBorderWidth( 0 );
-    ac1_1->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1181 ), 1, 0 ),
+    ac1_1->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1366 ), 1, 0 ),
                       0, 0, AContainer::CO_FIX );
     CycleButton *comparemode_cb = ac1_1->addWidget( new CycleButton( aguix, 0, 0, 10, 0 ),
                                                     1, 0, AContainer::CO_INCW );
-    comparemode_cb->addOption( catalog.getLocale( 1182 ) );
-    comparemode_cb->addOption( catalog.getLocale( 1183 ) );
-    comparemode_cb->addOption( catalog.getLocale( 1184 ) );
+    comparemode_cb->addOption( catalog.getLocale( 1367 ) );
+    comparemode_cb->addOption( catalog.getLocale( 1368 ) );
+    comparemode_cb->addOption( catalog.getLocale( 1369 ) );
+    comparemode_cb->addOption( catalog.getLocale( 1361 ) );
+    comparemode_cb->addOption( catalog.getLocale( 1362 ) );
+    comparemode_cb->addOption( catalog.getLocale( 1363 ) );
     comparemode_cb->resize( comparemode_cb->getMaxSize(),
                            comparemode_cb->getHeight() );
 
@@ -570,7 +752,16 @@ DirCompareOp::doConfigure()
                            resultmode_cb->getHeight() );
     ac0->readLimits();
     
-    AContainer *ac1_3 = ac0->add( new AContainer( win, 2, 1 ), 0, 3 );
+    AContainer *ac1_4 = ac0->add( new AContainer( win, 2, 1 ), 0, 3 );
+    ac1_4->setMinSpace( 5 );
+    ac1_4->setMaxSpace( 5 );
+    ac1_4->setBorderWidth( 0 );
+    ac1_4->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1364 ), 1, 0 ),
+                      0, 0, AContainer::CO_FIX );
+    StringGadget *limit_sg = ac1_4->addWidget( new StringGadget( aguix, 0, 0, 50, "", 0 ),
+                                               1, 0, AContainer::CO_INCW );
+
+    AContainer *ac1_3 = ac0->add( new AContainer( win, 2, 1 ), 0, 4 );
     ac1_3->setMinSpace( 5 );
     ac1_3->setMaxSpace( -1 );
     ac1_3->setBorderWidth( 0 );
@@ -611,13 +802,22 @@ DirCompareOp::doConfigure()
 
         switch ( comparemode_cb->getSelectedOption() ) {
             case 1:
-                m_compare_mode = COMPARE_SIZE_AND_MDATE;
+                m_compare_mode = COMPARE_FILENAME_FILESIZE;
                 break;
             case 2:
-                m_compare_mode = COMPARE_CONTENT;
+                m_compare_mode = COMPARE_FILENAME_FILESIZE_MDATE;
+                break;
+            case 3:
+                m_compare_mode = COMPARE_FILENAME_CONTENT;
+                break;
+            case 4:
+                m_compare_mode = COMPARE_FILESIZE;
+                break;
+            case 5:
+                m_compare_mode = COMPARE_CHECKSUM;
                 break;
             default:
-                m_compare_mode = COMPARE_SIZE;
+                m_compare_mode = COMPARE_FILENAME;
                 break;
         }
 
@@ -629,9 +829,22 @@ DirCompareOp::doConfigure()
                 m_result_mode = CHANGE_SELECTION_STATE;
                 break;
         }
+
+        if ( strlen( limit_sg->getText() ) > 0 ) {
+            m_file_size_limit = AGUIXUtils::convertHumanStringToNumber( limit_sg->getText() );
+        }
     }
 
     delete win;
 
+#ifndef HAVE_OPENSSL_SHA256
+    if ( m_compare_mode == COMPARE_CHECKSUM ) {
+        Worker::getRequester()->request( catalog.getLocale( 124 ),
+                                         catalog.getLocale( 1365 ),
+                                         catalog.getLocale( 8 ) );
+        return 1;
+    }
+#endif
+
     return endmode;
 }
