@@ -29,7 +29,7 @@
 #include "simplelist.hh"
 #include "wconfig.h"
 #include "wcfiletype.hh"
-#include <aguix/util.h>
+#include "aguix/util.h"
 #include "commonprefix.hh"
 
 DMCacheEntryNWC::DMCacheEntryNWC( std::unique_ptr< NWC::Dir > dir,
@@ -298,7 +298,7 @@ void DMCacheEntryNWC::setupEntries()
     m_entries.resize( m_dir->size(),
                       NWCEntrySelectionState() );
 
-    for ( int pos = 0; pos < m_dir->size(); pos++ ) {
+    for ( int pos = 0; pos < (int)m_dir->size(); pos++ ) {
         m_entries[pos].setEntryID( pos );
         m_entries[pos].setDir( m_dir );
         m_entries[pos].setUse( true );
