@@ -27,12 +27,12 @@
 #include "fileentry.hh"
 #include "worker_locale.h"
 #include "dnd.h"
-#include <aguix/cyclebutton.h>
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
-#include <aguix/request.h>
-#include <aguix/acontainer.h>
-#include <aguix/awindow.h>
+#include "aguix/cyclebutton.h"
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
+#include "aguix/request.h"
+#include "aguix/acontainer.h"
+#include "aguix/awindow.h"
 #include "datei.h"
 #include "nwc_path.hh"
 #include "argclass.hh"
