@@ -24,11 +24,11 @@
 #include "worker.h"
 #include "worker_locale.h"
 #include "datei.h"
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/acontainer.h>
-#include <aguix/lowlevelfunc.h>
-#include <aguix/awindow.h>
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/acontainer.h"
+#include "aguix/lowlevelfunc.h"
+#include "aguix/awindow.h"
 
 const char *EnterPathOp::name="EnterPathOp";
 
