@@ -22,7 +22,7 @@
 #include "execlass.h"
 #include <stdarg.h>
 #include "datei.h"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
