@@ -26,11 +26,11 @@
 #include "wpucontext.h"
 #include "execlass.h"
 #include "worker_locale.h"
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
-#include <aguix/awindow.h>
-#include <aguix/textstorage.h>
-#include <aguix/textview.h>
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
+#include "aguix/awindow.h"
+#include "aguix/textstorage.h"
+#include "aguix/textview.h"
 #include "virtualdirmode.hh"
 #include "nwc_path.hh"
 
