@@ -20,8 +20,8 @@
  */
 
 #include "fileentry.hh"
-#include <aguix/lowlevelfunc.h>
-#include <aguix/fieldlistviewdnd.h>
+#include "aguix/lowlevelfunc.h"
+#include "aguix/fieldlistviewdnd.h"
 #include "wconfig.h"
 #include "grouphash.h"
 #include "pdatei.h"
