@@ -22,14 +22,14 @@
 #include "fileviewer.hh"
 #include "fileviewerbg.hh"
 #include "worker.h"
-#include <aguix/textview.h>
+#include "aguix/textview.h"
 #include "textstoragefile.h"
 #include "nwc_fsentry.hh"
-#include <aguix/util.h>
-#include <aguix/refcount.hh>
+#include "aguix/util.h"
+#include "aguix/refcount.hh"
 #include "filenameshrinker.hh"
-#include <aguix/searchtextstorage.hh>
-#include <aguix/backgroundmessagehandler.hh>
+#include "aguix/searchtextstorage.hh"
+#include "aguix/backgroundmessagehandler.hh"
 
 bool FileViewer::global_wrap_mode = false;
 bool FileViewer::global_show_line_numbers_mode = false;
