@@ -22,17 +22,17 @@
 #include "fileviewerbg.hh"
 #include "fileviewer.hh"
 #include "worker.h"
-#include <aguix/textview.h>
+#include "aguix/textview.h"
 #include "textstoragefile.h"
 #include "nwc_fsentry.hh"
-#include <aguix/util.h>
-#include <aguix/refcount.hh>
+#include "aguix/util.h"
+#include "aguix/refcount.hh"
 #include "filenameshrinker.hh"
-#include <aguix/searchtextstorage.hh>
-#include <aguix/backgroundmessagehandler.hh>
-#include <aguix/choosebutton.h>
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
+#include "aguix/searchtextstorage.hh"
+#include "aguix/backgroundmessagehandler.hh"
+#include "aguix/choosebutton.h"
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "listermode.h"
