@@ -23,7 +23,7 @@
 #include "wconfig.h"
 #include "wcfiletype.hh"
 #include <algorithm>
-#include <aguix/fieldlistview.h>
+#include "aguix/fieldlistview.h"
 #include "simplelist.hh"
 
 FlatTypeList::FlatTypeList( List *types, const std::string &filter ) : m_filter( filter )
