@@ -1,6 +1,6 @@
 /* functionproto.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2017 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,10 +21,10 @@
 
 #include "functionproto.h"
 #include "worker.h"
-#include <aguix/util.h>
+#include "aguix/util.h"
 #include "fileentry.hh"
 #include "worker_locale.h"
-#include <aguix/request.h>
+#include "aguix/request.h"
 #include "simplelist.hh"
 #include "datei.h"
 
@@ -212,29 +212,18 @@ RefCount< NWC::VirtualDir > ActionMessage::getEntriesToConsider()
     return m_entries_to_consider;
 }
 
-std::string getStringReprForList( List *coms )
+std::string getStringReprForList( const command_list_t &coms )
 {
-    if ( ! coms ) return "";
-    
     std::string res;
-    FunctionProto *fp;
-    int id =coms->initEnum();
-
-    fp = (FunctionProto*)coms->getFirstElement( id );
-
-    while ( fp != NULL ) {
 
+    for ( auto &fp : coms ) {
         if ( ! res.empty() ) {
             res += "; ";
         }
 
         res += fp->getStringRepresentation();
-
-        fp = (FunctionProto*)coms->getNextElement( id );
     }
 
-    coms->closeEnum(id);
-
     return res;
 }
 
