@@ -25,10 +25,10 @@
 #include "avfssupport.hh"
 #include "worker_locale.h"
 #include "datei.h"
-#include <aguix/stringgadget.h>
-#include <aguix/choosebutton.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/button.h>
+#include "aguix/stringgadget.h"
+#include "aguix/choosebutton.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/button.h"
 #include "argclass.hh"
 #include "virtualdirmode.hh"
 
