@@ -40,8 +40,8 @@ void WConfig::setDefaultConfig()
   WCDoubleShortkey *key;
   WCButton *b1;
   WCHotkey *h1;
-  List *nc, *keylist;
-  FunctionProto *fp,*rfp;
+  List *keylist;
+  std::shared_ptr< FunctionProto > fp, rfp;
   int i;
 
   setLang("");
@@ -183,7 +183,7 @@ void WConfig::setDefaultConfig()
   delete np;
   
   // setup buttons
-  nc=new List();
+  command_list_t nc;
   nb=new List();
   
   b1=new WCButton();
@@ -193,15 +193,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "selectall" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
@@ -211,15 +211,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "selectnone" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
   
   b1=new WCButton();
@@ -229,15 +229,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "invertall" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
@@ -249,42 +249,42 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_KP_Divide,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new FilterSelectOp();
-  nc->addElement(fp);
+  fp = std::make_shared< FilterSelectOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
   b1->setText("PatternUnselect");
   b1->setCheck(true);
-  fp=new FilterUnSelectOp();
-  nc->addElement(fp);
+  fp = std::make_shared< FilterUnSelectOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
   b1->setText("Path2otherside");
   b1->setCheck(true);
-  fp=new Path2OSideOp();
-  nc->addElement(fp);
+  fp = std::make_shared< Path2OSideOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
   b1->setText("Active2Other");
   b1->setCheck(true);
-  fp=new EnterDirOp();
-  ((EnterDirOp*)fp)->setMode(EnterDirOp::ENTERDIROP_ACTIVE2OTHER);
-  nc->addElement(fp);
+  fp = std::make_shared< EnterDirOp >();
+  std::dynamic_pointer_cast< EnterDirOp >(fp)->setMode(EnterDirOp::ENTERDIROP_ACTIVE2OTHER);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
@@ -293,23 +293,23 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_u,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new ReloadOp();
-  ((ReloadOp*)fp)->setReloadside(ReloadOp::RELOADOP_THISSIDE);
-  nc->addElement(fp);
+  fp = std::make_shared< ReloadOp >();
+  std::dynamic_pointer_cast< ReloadOp >(fp)->setReloadside(ReloadOp::RELOADOP_THISSIDE);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
   b1->setText("Reload other");
   b1->setCheck(true);
-  fp=new ReloadOp();
-  ((ReloadOp*)fp)->setReloadside(ReloadOp::RELOADOP_OTHERSIDE);
-  nc->addElement(fp);
+  fp = std::make_shared< ReloadOp >();
+  std::dynamic_pointer_cast< ReloadOp >(fp)->setReloadside(ReloadOp::RELOADOP_OTHERSIDE);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   for(i=0;i<4;i++) nb->addElement(new WCButton());
@@ -324,13 +324,13 @@ void WConfig::setDefaultConfig()
   key->setType( WCDoubleShortkey::WCDS_DOUBLE );
   b1->setDoubleKeys( keylist );
   key->setType( WCDoubleShortkey::WCDS_NORMAL );
-  fp=new StartProgOp();
-  ((StartProgOp*)fp)->setStart(StartProgOp::STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY);
-  ((StartProgOp*)fp)->setRequestFlags(true);
-  nc->addElement(fp);
+  fp = std::make_shared< StartProgOp >();
+  std::dynamic_pointer_cast< StartProgOp >(fp)->setStart(StartProgOp::STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY);
+  std::dynamic_pointer_cast< StartProgOp >(fp)->setRequestFlags(true);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   for(i=0;i<13;i++) nb->addElement(new WCButton());
@@ -343,11 +343,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_F5,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new CopyOp();
-  nc->addElement(fp);
+  fp = std::make_shared< CopyOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
@@ -358,12 +358,12 @@ void WConfig::setDefaultConfig()
   key->setMod( ShiftMask, 0);
   key->setKeySym(XK_F5,0);
   b1->setDoubleKeys( keylist );
-  fp=new CopyOp();
-  ((CopyOp*)fp)->setRequestFlags(true);
-  nc->addElement(fp);
+  fp = std::make_shared< CopyOp >();
+  std::dynamic_pointer_cast< CopyOp >(fp)->setRequestFlags(true);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
@@ -374,11 +374,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_F8,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new DeleteOp();
-  nc->addElement(fp);
+  fp = std::make_shared< DeleteOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   nb->addElement(new WCButton());
@@ -391,11 +391,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_n,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new RenameOp();
-  nc->addElement(fp);
+  fp = std::make_shared< RenameOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   nb->addElement(new WCButton());
@@ -408,12 +408,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_F6,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new CopyOp();
-  ((CopyOp*)fp)->setMove(true);
-  nc->addElement(fp);
+  fp = std::make_shared< CopyOp >();
+  std::dynamic_pointer_cast< CopyOp >(fp)->setMove(true);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
@@ -424,13 +424,13 @@ void WConfig::setDefaultConfig()
   key->setMod( ShiftMask, 0 );
   key->setKeySym(XK_F6,0);
   b1->setDoubleKeys( keylist );
-  fp=new CopyOp();
-  ((CopyOp*)fp)->setMove(true);
-  ((CopyOp*)fp)->setRequestFlags(true);
-  nc->addElement(fp);
+  fp = std::make_shared< CopyOp >();
+  std::dynamic_pointer_cast< CopyOp >(fp)->setMove(true);
+  std::dynamic_pointer_cast< CopyOp >(fp)->setRequestFlags(true);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   b1=new WCButton();
@@ -443,12 +443,12 @@ void WConfig::setDefaultConfig()
   key->setType( WCDoubleShortkey::WCDS_DOUBLE );
   b1->setDoubleKeys( keylist );
   key->setType( WCDoubleShortkey::WCDS_NORMAL );
-  fp=new CreateSymlinkOp();
-  ((CreateSymlinkOp*)fp)->setRequestFlags(true);
-  nc->addElement(fp);
+  fp = std::make_shared< CreateSymlinkOp >();
+  std::dynamic_pointer_cast< CreateSymlinkOp >(fp)->setRequestFlags(true);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   nb->addElement(new WCButton());
@@ -456,14 +456,14 @@ void WConfig::setDefaultConfig()
   b1=new WCButton();
   b1->setText("new dir");
   b1->setCheck(true);
-  fp=new MakeDirOp();
+  fp = std::make_shared< MakeDirOp >();
   key->setKeySym(XK_F7,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  nc->addElement(fp);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   nb->addElement(new WCButton());
@@ -473,14 +473,14 @@ void WConfig::setDefaultConfig()
   b1=new WCButton();
   b1->setText("Show");
   b1->setCheck(true);
-  fp=new InternalViewOp();
+  fp = std::make_shared< InternalViewOp >();
   key->setKeySym(XK_F3,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  nc->addElement(fp);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   nb->addElement(new WCButton());
@@ -491,15 +491,15 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_F4,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new OwnOp();
-  ((OwnOp*)fp)->setComStr("{scripts}/xeditor {A}");
-  nc->addElement(fp);
-  rfp=new ReloadOp();
-  nc->addElement(rfp);
+  fp = std::make_shared< OwnOp >();
+  std::dynamic_pointer_cast< OwnOp >(fp)->setComStr("{scripts}/xeditor {A}");
+  nc.push_back(fp);
+  rfp = std::make_shared< ReloadOp >();
+  nc.push_back(rfp);
   b1->setComs(nc);
-  delete fp;
-  delete rfp;
-  nc->removeAllElements();
+  fp.reset();
+  rfp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   for(i=0;i<5;i++) nb->addElement(new WCButton());
@@ -514,11 +514,11 @@ void WConfig::setDefaultConfig()
   key->setType( WCDoubleShortkey::WCDS_DOUBLE );
   b1->setDoubleKeys( keylist );
   key->setType( WCDoubleShortkey::WCDS_NORMAL );
-  fp=new ChangeSymlinkOp();
-  nc->addElement(fp);
+  fp = std::make_shared< ChangeSymlinkOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   for(i=0;i<3;i++) nb->addElement(new WCButton());
@@ -526,11 +526,11 @@ void WConfig::setDefaultConfig()
   b1=new WCButton();
   b1->setText("DirSize");
   b1->setCheck(true);
-  fp=new DirSizeOp();
-  nc->addElement(fp);
+  fp = std::make_shared< DirSizeOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   for(i=0;i<15;i++) nb->addElement(new WCButton());
@@ -545,12 +545,12 @@ void WConfig::setDefaultConfig()
   key->setType( WCDoubleShortkey::WCDS_DOUBLE );
   b1->setDoubleKeys( keylist );
   key->setType( WCDoubleShortkey::WCDS_NORMAL );
-  fp=new ChModOp();
-  ((ChModOp*)fp)->setRequestFlags(true);
-  nc->addElement(fp);
+  fp = std::make_shared< ChModOp >();
+  std::dynamic_pointer_cast< ChModOp >(fp)->setRequestFlags(true);
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   for(i=0;i<3;i++) nb->addElement(new WCButton());
@@ -561,11 +561,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_v,0);
   key->setMod( Mod1Mask, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new VolumeManagerOp();
-  nc->addElement(fp);
+  fp = std::make_shared< VolumeManagerOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   nb->addElement(new WCButton());
@@ -576,11 +576,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_b,0);
   key->setMod( Mod1Mask, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new DirBookmarkOp();
-  nc->addElement(fp);
+  fp = std::make_shared< DirBookmarkOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   nb->addElement(new WCButton());
@@ -592,11 +592,11 @@ void WConfig::setDefaultConfig()
   b1->setCheck(true);
   b1->setFG(2);
   b1->setBG(1);
-  fp=new QuitOp();
-  nc->addElement(fp);
+  fp = std::make_shared< QuitOp >();
+  nc.push_back(fp);
   b1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nb->addElement(b1);
 
   nb->addElement(new WCButton());
@@ -621,15 +621,15 @@ void WConfig::setDefaultConfig()
   h1->setDoubleKeys( keylist );
 
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "up" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -638,15 +638,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "down" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -654,11 +654,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_asciicircum,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new ChangeHiddenFlag();
-  nc->addElement(fp);
+  fp = std::make_shared< ChangeHiddenFlag >();
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -667,15 +667,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "first" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -684,15 +684,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "last" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -701,15 +701,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "pageup" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -718,15 +718,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "pagedown" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -735,15 +735,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "selectentry" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -752,15 +752,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "parentdir" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -768,11 +768,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Right,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new EnterDirOp();
-  nc->addElement(fp);
+  fp = std::make_shared< EnterDirOp >();
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -780,11 +780,11 @@ void WConfig::setDefaultConfig()
   key->setMod( Mod1Mask, 0 );
   key->setKeySym(XK_F1,0);
   h1->setDoubleKeys( keylist );
-  fp=new ChangeListerSetOp();
-  nc->addElement(fp);
+  fp = std::make_shared< ChangeListerSetOp >();
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -792,12 +792,12 @@ void WConfig::setDefaultConfig()
   key->setMod( Mod1Mask, 0 );
   key->setKeySym(XK_F2,0);
   h1->setDoubleKeys( keylist );
-  fp=new ChangeListerSetOp();
-  ((ChangeListerSetOp*)fp)->setMode(ChangeListerSetOp::CLS_RIGHT_LISTER);
-  nc->addElement(fp);
+  fp = std::make_shared< ChangeListerSetOp >();
+  std::dynamic_pointer_cast< ChangeListerSetOp >(fp)->setMode(ChangeListerSetOp::CLS_RIGHT_LISTER);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -805,11 +805,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Tab,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new SwitchListerOp();
-  nc->addElement(fp);
+  fp = std::make_shared< SwitchListerOp >();
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -818,15 +818,15 @@ void WConfig::setDefaultConfig()
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
   {
-      auto tfp = new ScriptOp();
+      auto tfp = std::make_shared< ScriptOp >();
       tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
       tfp->setCommandStr( "simulate_doubleclick" );
       fp = tfp;
   }
-  nc->addElement(fp);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -834,11 +834,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_s,0);
   key->setMod( ControlMask, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new SearchEntryOp();
-  nc->addElement(fp);
+  fp = std::make_shared< SearchEntryOp >();
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -846,11 +846,11 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Return,0);
   key->setMod( ControlMask, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new EnterPathOp();
-  nc->addElement(fp);
+  fp = std::make_shared< EnterPathOp >();
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -858,12 +858,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Return,0);
   key->setMod( ControlMask | ShiftMask, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new EnterPathOp();
-  ((EnterPathOp*)fp)->setSide(EnterPathOp::ENTERPATHOP_OTHERSIDE);
-  nc->addElement(fp);
+  fp = std::make_shared< EnterPathOp >();
+  std::dynamic_pointer_cast< EnterPathOp >(fp)->setSide(EnterPathOp::ENTERPATHOP_OTHERSIDE);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -871,12 +871,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Left,0);
   key->setMod( ControlMask, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new ScrollListerOp();
-  ((ScrollListerOp*)fp)->setDir(ScrollListerOp::SCROLLLISTEROP_LEFT);
-  nc->addElement(fp);
+  fp = std::make_shared< ScrollListerOp >();
+  std::dynamic_pointer_cast< ScrollListerOp >(fp)->setDir(ScrollListerOp::SCROLLLISTEROP_LEFT);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   h1=new WCHotkey();
@@ -884,12 +884,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Right,0);
   key->setMod( ControlMask, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new ScrollListerOp();
-  ((ScrollListerOp*)fp)->setDir(ScrollListerOp::SCROLLLISTEROP_RIGHT);
-  nc->addElement(fp);
+  fp = std::make_shared< ScrollListerOp >();
+  std::dynamic_pointer_cast< ScrollListerOp >(fp)->setDir(ScrollListerOp::SCROLLLISTEROP_RIGHT);
+  nc.push_back(fp);
   h1->setComs(nc);
-  delete fp;
-  nc->removeAllElements();
+  fp.reset();
+  nc.clear();
   nh->addElement(h1);
 
   setHotkeys(nh);
@@ -906,7 +906,6 @@ void WConfig::setDefaultConfig()
   delete nf;
   initFixTypes();
 
-  delete nc;
   delete key;
   delete keylist;
 }
