@@ -29,10 +29,10 @@
 #include "wcfiletype.hh"
 #include "fileentry.hh"
 #include "nmspecialsourceext.hh"
-#include <aguix/acontainer.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/awindow.h>
-#include <aguix/util.h>
+#include "aguix/acontainer.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/awindow.h"
+#include "aguix/util.h"
 #include "datei.h"
 #include "nwc_path.hh"
 #include "nwcentryselectionstate.hh"
