@@ -30,11 +30,11 @@
 #include "fileentry.hh"
 #include "worker_locale.h"
 #include "datei.h"
-#include <aguix/cyclebutton.h>
-#include <aguix/button.h>
-#include <aguix/choosebutton.h>
-#include <aguix/stringgadget.h>
-#include <aguix/awindow.h>
+#include "aguix/cyclebutton.h"
+#include "aguix/button.h"
+#include "aguix/choosebutton.h"
+#include "aguix/stringgadget.h"
+#include "aguix/awindow.h"
 #include "dnd.h"
 
 const char *InternalViewOp::name = "InternalViewOp";
