@@ -22,9 +22,9 @@
 #include "listermode.h"
 #include "datei.h"
 #include "execlass.h"
-#include <aguix/lowlevelfunc.h>
-#include <aguix/util.h>
-#include <aguix/request.h>
+#include "aguix/lowlevelfunc.h"
+#include "aguix/util.h"
+#include "aguix/request.h"
 #include "worker_locale.h"
 #include "worker.h"
 #include "argclass.hh"
