@@ -23,9 +23,9 @@
 #define LISTERMODE_H
 
 #include "wdefines.h"
-#include <aguix/message.h>
+#include "aguix/message.h"
 #include "generic_callback.hh"
-#include <aguix/refcount.hh>
+#include "aguix/refcount.hh"
 #include "lister.h"
 #include "nmspecialsourceext.hh"
 #include <map>
