@@ -23,14 +23,14 @@
 #include "worker.h"
 #include "nwc_path.hh"
 #include "menutree.hh"
-#include <aguix/aguix.h>
-#include <aguix/awindow.h>
-#include <aguix/button.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/stringgadget.h>
-#include <aguix/textview.h>
-#include <aguix/utf8.hh>
-#include <aguix/choosebutton.h>
+#include "aguix/aguix.h"
+#include "aguix/awindow.h"
+#include "aguix/button.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/stringgadget.h"
+#include "aguix/textview.h"
+#include "aguix/utf8.hh"
+#include "aguix/choosebutton.h"
 #include <algorithm>
 #include <iostream>
 #include "prefixdb.hh"
