@@ -22,11 +22,11 @@
 #include "modifytabsop.hh"
 #include "listermode.h"
 #include "worker.h"
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/solidbutton.h>
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/solidbutton.h"
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
 #include "worker_locale.h"
 #include "datei.h"
 #include "argclass.hh"
