@@ -24,7 +24,7 @@
 #include "configparser.hh"
 #include "wconfig.h"
 #include "datei.h"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 
 NM_Filter::NM_Filter()
 {
