@@ -26,10 +26,10 @@
 #include "nwc_path.hh"
 #include "pers_string_list.hh"
 #include "worker_locale.h"
-#include <aguix/cyclebutton.h>
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
-#include <aguix/fieldlistview.h>
+#include "aguix/cyclebutton.h"
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
+#include "aguix/fieldlistview.h"
 #include "datei.h"
 #include "virtualdirmode.hh"
 #include "argclass.hh"
