@@ -311,7 +311,7 @@ namespace NWC
     return _walk_mode;
   }
 
-  int Dir::size() const
+  size_t Dir::size() const
   {
     return _subentries.size();
   }
@@ -385,9 +385,9 @@ namespace NWC
       return l;
   }
 
-    FSEntry *Dir::getEntryAtPos( int pos )
+    FSEntry *Dir::getEntryAtPos( size_t pos )
     {
-        if ( pos < 0 || pos >= (int)_subentries.size() ) return NULL;
+        if ( pos < 0 || pos >= _subentries.size() ) return NULL;
 
         return _subentries[pos];
     }
