@@ -21,7 +21,7 @@
 
 #include "nwc_fsentry.hh"
 #include "grouphash.h"
-#include <aguix/util.h>
+#include "aguix/util.h"
 #include <string.h>  //memcpy
 #include "nwc_path.hh"
 #include "nwc_os.hh"
