@@ -21,8 +21,8 @@
 
 #include "nwc_path.hh"
 #include "nwc_os.hh"
-#include <aguix/lowlevelfunc.h>
-#include <aguix/util.h>
+#include "aguix/lowlevelfunc.h"
+#include "aguix/util.h"
 
 namespace NWC {
     namespace Path {
