@@ -25,9 +25,9 @@
 #include "worker_locale.h"
 #include "worker.h"
 #include "datei.h"
-#include <aguix/choosebutton.h>
-#include <aguix/button.h>
-#include <aguix/awindow.h>
+#include "aguix/choosebutton.h"
+#include "aguix/button.h"
+#include "aguix/awindow.h"
 
 const char *OpenContextMenuOp::name = "OpenContextMenuOp";
 
