@@ -23,13 +23,13 @@
 #include "worker.h"
 #include "filereq.h"
 #include "datei.h"
-#include <aguix/button.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/stringgadget.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/choosebutton.h>
-#include <aguix/acontainer.h>
-#include <aguix/awindow.h>
+#include "aguix/button.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/stringgadget.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/choosebutton.h"
+#include "aguix/acontainer.h"
+#include "aguix/awindow.h"
 #include "worker_locale.h"
 #include "dnd.h"
 #include "wpucontext.h"
