@@ -65,7 +65,7 @@ ParentActionOp::run( WPUContext *wpu, ActionMessage *msg )
     ft = msg->filetype->getParentType();
     if ( ft != NULL ) {
       ActionMessage amsg2( msg->getWorker() );
-      List *l1;
+      command_list_t l1;
  
       amsg2.mode = msg->mode;
       amsg2.startLister = msg->startLister;
@@ -83,9 +83,7 @@ ParentActionOp::run( WPUContext *wpu, ActionMessage *msg )
       amsg2.m_action_descr = msg->m_action_descr;
 
       if ( msg->m_action_descr.getVal() != NULL ) {
-	l1 = ft->getActionList( false, *(msg->m_action_descr) );
-      } else {
-	l1 = NULL;
+          l1 = ft->getActionList( false, *(msg->m_action_descr) );
       }
 
       msg->getWorker()->interpret( l1, &amsg2 );
