@@ -30,10 +30,10 @@
 #include "nwc_path.hh"
 #include "virtualdirmode.hh"
 #include "datei.h"
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
 
 const char *PathJumpOp::name = "PathJumpOp";
 
