@@ -20,7 +20,7 @@
  */
 
 #include "pdatei.h"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 #include "worker_lfs.h"
 #include "nwc_fsentry.hh"
 
