@@ -24,15 +24,15 @@
 #include "worker.h"
 #include "wpucontext.h"
 #include "execlass.h"
-#include <aguix/acontainerbb.h>
+#include "aguix/acontainerbb.h"
 #include "worker_locale.h"
-#include <aguix/fieldlistview.h>
-#include <aguix/choosebutton.h>
-#include <aguix/stringgadget.h>
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/awindow.h>
-#include <aguix/request.h>
+#include "aguix/fieldlistview.h"
+#include "aguix/choosebutton.h"
+#include "aguix/stringgadget.h"
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/awindow.h"
+#include "aguix/request.h"
 #include "datei.h"
 #include "wconfig.h"
 
