@@ -23,11 +23,11 @@
 #include "listermode.h"
 #include "worker.h"
 #include "flagreplacer.hh"
-#include <aguix/acontainerbb.h>
-#include <aguix/kartei.h>
-#include <aguix/stringgadget.h>
-#include <aguix/choosebutton.h>
-#include <aguix/button.h>
+#include "aguix/acontainerbb.h"
+#include "aguix/kartei.h"
+#include "aguix/stringgadget.h"
+#include "aguix/choosebutton.h"
+#include "aguix/button.h"
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "datei.h"
