@@ -27,13 +27,13 @@
 #include "nwc_virtualdir.hh"
 #include "fileviewer.hh"
 #include "flagreplacer.hh"
-#include <aguix/acontainerbb.h>
+#include "aguix/acontainerbb.h"
 #include <typeinfo>
 #include "filenameshrinker.hh"
-#include <aguix/kartei.h>
-#include <aguix/stringgadget.h>
-#include <aguix/choosebutton.h>
-#include <aguix/button.h>
+#include "aguix/kartei.h"
+#include "aguix/stringgadget.h"
+#include "aguix/choosebutton.h"
+#include "aguix/button.h"
 #include "calendar.hh"
 #include "worker_locale.h"
 #include "wconfig.h"
