@@ -20,7 +20,7 @@
  */
 
 #include "searchthread.hh"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 #include "nwc_file.hh"
 #include "pdatei.h"
 #include "worker_locale.h"
