@@ -22,7 +22,7 @@
 #include "setfilterop.h"
 #include "listermode.h"
 #include "worker.h"
-#include <aguix/acontainerbb.h>
+#include "aguix/acontainerbb.h"
 #include "bookmarkdbproxy.hh"
 #include <algorithm>
 #include "workerinitialsettings.hh"
@@ -30,11 +30,11 @@
 #include "pers_string_list.hh"
 #include "datei.h"
 #include "worker_locale.h"
-#include <aguix/cyclebutton.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/choosebutton.h>
-#include <aguix/stringgadget.h>
-#include <aguix/button.h>
+#include "aguix/cyclebutton.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/choosebutton.h"
+#include "aguix/stringgadget.h"
+#include "aguix/button.h"
 #include "wconfig.h"
 #include "virtualdirmode.hh"
 
