@@ -24,9 +24,9 @@
 #include "worker.h"
 #include "verzeichnis.hh"
 #include "datei.h"
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/choosebutton.h>
+#include "aguix/button.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/choosebutton.h"
 #include "worker_locale.h"
 #include "virtualdirmode.hh"
 
