@@ -24,9 +24,9 @@
 #include "virtualdirmode.hh"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/stringgadget.h>
-#include <aguix/button.h>
-#include <aguix/fieldlistview.h>
+#include "aguix/stringgadget.h"
+#include "aguix/button.h"
+#include "aguix/fieldlistview.h"
 #include "nwc_path.hh"
 #include "argclass.hh"
 #include <algorithm>
