@@ -23,8 +23,8 @@
 #include "listermode.h"
 #include "worker.h"
 #include <string>
-#include <aguix/kartei.h>
-#include <aguix/acontainerbb.h>
+#include "aguix/kartei.h"
+#include "aguix/acontainerbb.h"
 #include "execlass.h"
 #include "basic_actions.h"
 #include "wcfiletype.hh"
@@ -35,12 +35,12 @@
 #include "processexitaction.hh"
 #include "datei.h"
 #include "worker_locale.h"
-#include <aguix/fieldlistview.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/choosebutton.h>
-#include <aguix/stringgadget.h>
-#include <aguix/button.h>
-#include <aguix/textview.h>
+#include "aguix/fieldlistview.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/choosebutton.h"
+#include "aguix/stringgadget.h"
+#include "aguix/button.h"
+#include "aguix/textview.h"
 #include "wconfig.h"
 #include "flattypelist.hh"
 #include "argclass.hh"
@@ -375,17 +375,15 @@ StartProgOp::startprog( WPUContext *wpu, ActionMessage *am )
   } else if ( m1->_startmode == StartSettings::HANDLE_TYPE ) {
     WCFiletype *ft = m1->_type;
     if ( ( ft != NULL ) && ( tfe != NULL ) ) {
-      List *l = ft->getDoubleClickActions();
-      if ( l != NULL ) {
-	ActionMessage amsg( am->getWorker() );
+      auto l = ft->getDoubleClickActions();
+      ActionMessage amsg( am->getWorker() );
 	
-	amsg.mode = amsg.AM_MODE_SPECIAL;
+      amsg.mode = amsg.AM_MODE_SPECIAL;
 	
-	amsg.setFE( tfe );
-	amsg.filetype = ft;
-        amsg.m_action_descr = RefCount<ActionDescr>( new DoubleClickAction::DoubleClickActionDescr() );
-	am->getWorker()->interpret( l, &amsg );
-      }
+      amsg.setFE( tfe );
+      amsg.filetype = ft;
+      amsg.m_action_descr = RefCount<ActionDescr>( new DoubleClickAction::DoubleClickActionDescr() );
+      am->getWorker()->interpret( l, &amsg );
     }
   } else if ( m1->_startmode == StartSettings::HANDLE_ARCHIVE ) {
     std::string dir;
