@@ -20,8 +20,8 @@
  */
 
 #include "stringmatcher_flexiblematch.hh"
-#include <aguix/lowlevelfunc.h>
-#include <aguix/utf8.hh>
+#include "aguix/lowlevelfunc.h"
+#include "aguix/utf8.hh"
 #include <cctype>
 #include <algorithm>
 #include <functional>
