@@ -21,14 +21,14 @@
 
 #include "switchbuttonbankop.hh"
 #include "worker.h"
-#include <aguix/cyclebutton.h>
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
-#include <aguix/lowlevelfunc.h>
-#include <aguix/acontainer.h>
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/util.h>
+#include "aguix/cyclebutton.h"
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
+#include "aguix/lowlevelfunc.h"
+#include "aguix/acontainer.h"
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/util.h"
 #include "datei.h"
 #include "worker_locale.h"
 
