@@ -22,15 +22,15 @@
 #include "tabprofilesop.hh"
 #include "listermode.h"
 #include "worker.h"
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/acontainerbb.h>
-#include <aguix/kartei.h>
-#include <aguix/textview.h>
-#include <aguix/request.h>
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/acontainerbb.h"
+#include "aguix/kartei.h"
+#include "aguix/textview.h"
+#include "aguix/request.h"
 #include "worker_locale.h"
 #include "virtualdirmode.hh"
 #include "workerinitialsettings.hh"
