@@ -20,13 +20,13 @@
  */
 
 #include "view_newest_files_op.hh"
-#include <aguix/aguix.h>
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
-#include <aguix/textstorage.h>
-#include <aguix/textview.h>
+#include "aguix/aguix.h"
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
+#include "aguix/textstorage.h"
+#include "aguix/textview.h"
 #include "listermode.h"
 #include "nwc_fsentry.hh"
 #include "nmspecialsourceext.hh"
