@@ -20,15 +20,15 @@
  */
 
 #include "virtualdirmode.hh"
-#include <aguix/acontainer.h>
-#include <aguix/fieldlistviewdnd.h>
-#include <aguix/awindow.h>
-#include <aguix/stringgadget.h>
-#include <aguix/kartei.h>
-#include <aguix/karteibutton.h>
-#include <aguix/button.h>
-#include <aguix/acontainerbb.h>
-#include <aguix/choosebutton.h>
+#include "aguix/acontainer.h"
+#include "aguix/fieldlistviewdnd.h"
+#include "aguix/awindow.h"
+#include "aguix/stringgadget.h"
+#include "aguix/kartei.h"
+#include "aguix/karteibutton.h"
+#include "aguix/button.h"
+#include "aguix/acontainerbb.h"
+#include "aguix/choosebutton.h"
 #include "worker_locale.h"
 #include "worker.h"
 #include "wconfig.h"
