@@ -20,7 +20,7 @@
  */
 
 #include "virtualdirmode.hh"
-#include <aguix/fieldlistviewdnd.h>
+#include "aguix/fieldlistviewdnd.h"
 #include "worker_locale.h"
 #include "worker.h"
 #include "nwcentryselectionstate.hh"
@@ -186,8 +186,25 @@ void VirtualDirMode::copy( std::shared_ptr< struct copyorder > co )
 
     if ( cc->buildCopyDatabase() != 0 ) cc->setCancel( true );
 
+    bool skip_space_test = false;
+
+    // this is an simple assumption to skip the space test if both
+    // base directories are on the same device. Moving will probably
+    // not taking any disk space. This is of course not accurate as
+    // sub-dirs can be on different devices, or rename could still
+    // fail on the same device, etc.
+    if ( co->move ) {
+        NWC::FSEntry source( getCurrentDirectory() );
+        NWC::FSEntry dest( co->destdir );
+
+        if ( dest.stat_dev() ==
+             source.stat_dev() ) {
+            skip_space_test = true;
+        }
+    }
+    
     // this is just the value from the last update, it might not be correct
-    if ( parentlister->getWorker()->PS_readSpace( co->destdir.c_str() ) == 0 ) {
+    if ( ! skip_space_test && parentlister->getWorker()->PS_readSpace( co->destdir.c_str() ) == 0 ) {
         loff_t total_space = parentlister->getWorker()->PS_getSpace();
         loff_t free_blocks = parentlister->getWorker()->PS_getFreeSpace();
         loff_t block_size = parentlister->getWorker()->PS_getBlocksize();
