@@ -21,7 +21,7 @@
 
 #include "virtualdirmode.hh"
 #include "worker.h"
-#include <aguix/fieldlistviewdnd.h>
+#include "aguix/fieldlistviewdnd.h"
 
 void VirtualDirMode::vdir_from_selected()
 {
