@@ -20,12 +20,12 @@
  */
 
 #include "volumemanagerui.hh"
-#include <aguix/aguix.h>
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
-#include <aguix/solidbutton.h>
+#include "aguix/aguix.h"
+#include "aguix/awindow.h"
+#include "aguix/text.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
+#include "aguix/solidbutton.h"
 #include <algorithm>
 #include "hw_volume.hh"
 #include "hw_volume_manager.hh"
@@ -33,8 +33,8 @@
 #include "nwc_path.hh"
 #include "worker.h"
 #include "pers_string_list.hh"
-#include <aguix/textview.h>
-#include <aguix/popupmenu.hh>
+#include "aguix/textview.h"
+#include "aguix/popupmenu.hh"
 #include "worker_locale.h"
 
 VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_aguix( aguix ),
