@@ -28,7 +28,7 @@
 #include <list>
 #include <map>
 #include "layoutsettings.hh"
-#include <aguix/aguix.h>
+#include "aguix/aguix.h"
 #include "stringcomparator.hh"
 #include "wconfig_types.hh"
 #include "wconfig_initial_command.hh"
@@ -422,12 +422,12 @@ protected:
   static bool always_keep_old_key;
 
   bool configureHotkey(WCHotkey*);
-  FunctionProto *requestCommand( bool &dontConfigure );
+  std::shared_ptr< FunctionProto > requestCommand( bool &dontConfigure );
   static int requestCommand_sf(void*,void*);
 
   bool configureButton(WCButton*);
   //bool configureFiletype(WCFiletype*);
-  void showFTActions( const char*, WCFiletype*, FieldListView*, List** );
+    void showFTActions( const char*, WCFiletype*, FieldListView*, command_list_t *return_list, std::string &write_back_name );
   bool changeFiledesc(WCFiletype*);
   char *getStr4Char(int,short);
   int WCEditByte(int ch);
