@@ -22,11 +22,11 @@
 #include "wconfig_button.hh"
 #include "wconfig.h"
 #include "worker.h"
-#include <aguix/acontainerbb.h>
-#include <aguix/button.h>
-#include <aguix/solidbutton.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/fieldlistview.h>
+#include "aguix/acontainerbb.h"
+#include "aguix/button.h"
+#include "aguix/solidbutton.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/fieldlistview.h"
 #include "wcbutton.hh"
 #include "worker_locale.h"
 #include "simplelist.hh"
