@@ -23,7 +23,7 @@
 #include "wconfig.h"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/stringgadget.h>
+#include "aguix/stringgadget.h"
 
 ButtonGrpConfPanel::ButtonGrpConfPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
