@@ -23,9 +23,9 @@
 #include "wconfig.h"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/cyclebutton.h>
-#include <aguix/stringgadget.h>
-#include <aguix/choosebutton.h>
+#include "aguix/cyclebutton.h"
+#include "aguix/stringgadget.h"
+#include "aguix/choosebutton.h"
 
 ClockPanel::ClockPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
