@@ -23,10 +23,10 @@
 #include "wconfig.h"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/button.h>
-#include <aguix/solidbutton.h>
-#include <aguix/bevelbox.h>
-#include <aguix/fieldlistview.h>
+#include "aguix/button.h"
+#include "aguix/solidbutton.h"
+#include "aguix/bevelbox.h"
+#include "aguix/fieldlistview.h"
 
 ColorPanel::ColorPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
