@@ -25,8 +25,8 @@
 #include "worker.h"
 #include "worker_locale.h"
 #include "simplelist.hh"
-#include <aguix/stringgadget.h>
-#include <aguix/button.h>
+#include "aguix/stringgadget.h"
+#include "aguix/button.h"
 
 ColorConfPanel::ColorConfPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
