@@ -1,6 +1,6 @@
 /* wconfig_dcd.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,9 +23,9 @@
 #include "wconfig.h"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
-#include <aguix/choosebutton.h>
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
+#include "aguix/choosebutton.h"
 #include "simplelist.hh"
 #include "datei.h"
 #include "nwc_path.hh"
@@ -61,6 +61,8 @@ int DCDPanel::create()
   filv =(FieldListView*)ac1->add( new FieldListView( _aguix, 0, 0, 100, 100, 0 ), 0, 1, AContainer::CO_MIN );
   filv->setHBarState(2);
   filv->setVBarState(2);
+  filv->setAcceptFocus( true );
+  filv->setDisplayFocus( true );
 
   AContainer *ac1_1 = ac1->add( new AContainer( this, 3, 1 ), 0, 2 );
   ac1_1->setMinSpace( 0 );
