@@ -23,12 +23,12 @@
 #include "wconfig.h"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
-#include <aguix/choosebutton.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/acontainerbb.h>
-#include <aguix/stringgadget.h>
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
+#include "aguix/choosebutton.h"
+#include "aguix/cyclebutton.h"
+#include "aguix/acontainerbb.h"
+#include "aguix/stringgadget.h"
 #include "datei.h"
 #include "nwc_path.hh"
 #include "verzeichnis.hh"
