@@ -24,9 +24,9 @@
 #include "worker.h"
 #include "wcfiletype.hh"
 #include "worker_locale.h"
-#include <aguix/stringgadget.h>
-#include <aguix/button.h>
-#include <aguix/fieldlistview.h>
+#include "aguix/stringgadget.h"
+#include "aguix/button.h"
+#include "aguix/fieldlistview.h"
 #include "flattypelist.hh"
 #include "simplelist.hh"
 
