@@ -22,10 +22,10 @@
 #include "wconfig_generalconf.hh"
 #include "wconfig.h"
 #include "worker.h"
-#include <aguix/acontainerbb.h>
+#include "aguix/acontainerbb.h"
 #include "worker_locale.h"
-#include <aguix/choosebutton.h>
-#include <aguix/cyclebutton.h>
+#include "aguix/choosebutton.h"
+#include "aguix/cyclebutton.h"
 
 GeneralConfPanel::GeneralConfPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
