@@ -1,6 +1,6 @@
 /* wconfig_hotkey.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,8 +24,8 @@
 #include "worker.h"
 #include "wchotkey.hh"
 #include "worker_locale.h"
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
 #include "simplelist.hh"
 
 HotkeyPanel::HotkeyPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
@@ -54,6 +54,8 @@ int HotkeyPanel::create()
   lv = (FieldListView*)ac1->add( new FieldListView( _aguix, 0, 0, 200, 150, 0 ), 0, 1, AContainer::CO_MIN );
   lv->setHBarState(2);
   lv->setVBarState(2);
+  lv->setAcceptFocus( true );
+  lv->setDisplayFocus( true );
 
   AContainer *ac1_1 = ac1->add( new AContainer( this, 4, 1 ), 0, 2 );
   ac1_1->setMinSpace( 0 );
