@@ -21,8 +21,8 @@
 
 #include "wconfig_imexport.hh"
 #include "wconfig.h"
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
 #include <memory>
 #include "worker_locale.h"
 #include "filereq.h"
