@@ -22,13 +22,13 @@
 #include "wconfig_layout.hh"
 #include "wconfig.h"
 #include "worker.h"
-#include <aguix/acontainerbb.h>
+#include "aguix/acontainerbb.h"
 #include <algorithm>
-#include <aguix/slider.h>
-#include <aguix/choosebutton.h>
-#include <aguix/solidbutton.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
+#include "aguix/slider.h"
+#include "aguix/choosebutton.h"
+#include "aguix/solidbutton.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
 #include <sstream>
 #include "worker_locale.h"
 
