@@ -22,10 +22,10 @@
 #include "wconfig_lister.hh"
 #include "wconfig.h"
 #include "worker.h"
-#include <aguix/acontainerbb.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/choosebutton.h>
-#include <aguix/stringgadget.h>
+#include "aguix/acontainerbb.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/choosebutton.h"
+#include "aguix/stringgadget.h"
 #include "worker_locale.h"
 
 ListerPanel::ListerPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
