@@ -1,6 +1,6 @@
 /* wconfig_listview.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,9 +22,9 @@
 #include "wconfig_listview.hh"
 #include "wconfig.h"
 #include "worker.h"
-#include <aguix/acontainerbb.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
+#include "aguix/acontainerbb.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
 #include "worker_locale.h"
 
 ListViewPanel::ListViewPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
@@ -101,6 +101,8 @@ int ListViewPanel::create()
     downb[side]->connect( this );
     lv1[side]->setHBarState(2);
     lv1[side]->setVBarState(2);
+    lv1[side]->setAcceptFocus( true );
+    lv1[side]->setDisplayFocus( true );
     
     AContainer *ac1_1_2 = ac1_1->add( new AContainer( this, 1, 4 ), 1, 0 );
     ac1_1_2->setMinSpace( 5 );
@@ -131,6 +133,8 @@ int ListViewPanel::create()
     lv2[side]->connect( this );
     lv2[side]->setHBarState(2);
     lv2[side]->setVBarState(2);
+    lv2[side]->setAcceptFocus( true );
+    lv2[side]->setDisplayFocus( true );
     
     bool *sels = new bool[WorkerTypes::getAvailListColsSize()];
     for ( j = 0; j < WorkerTypes::getAvailListColsSize(); j++ ) {
