@@ -22,8 +22,8 @@
 #include "wconfig_mouse.hh"
 #include "wconfig.h"
 #include "worker.h"
-#include <aguix/acontainerbb.h>
-#include <aguix/cyclebutton.h>
+#include "aguix/acontainerbb.h"
+#include "aguix/cyclebutton.h"
 #include "worker_locale.h"
 
 MousePanel::MousePanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
