@@ -25,13 +25,13 @@
 #include "worker.h"
 #include <string>
 #include <sstream>
-#include <aguix/acontainer.h>
-#include <aguix/acontainerbb.h>
-#include <aguix/kartei.h>
-#include <aguix/slider.h>
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
-#include <aguix/solidbutton.h>
+#include "aguix/acontainer.h"
+#include "aguix/acontainerbb.h"
+#include "aguix/kartei.h"
+#include "aguix/slider.h"
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
+#include "aguix/solidbutton.h"
 #include "worker_locale.h"
 #include "simplelist.hh"
 
