@@ -24,9 +24,9 @@
 #include "wcpath.hh"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/button.h>
-#include <aguix/solidbutton.h>
-#include <aguix/cyclebutton.h>
+#include "aguix/button.h"
+#include "aguix/solidbutton.h"
+#include "aguix/cyclebutton.h"
 #include "simplelist.hh"
 
 PathPanel::PathPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
