@@ -1,6 +1,6 @@
 /* wconfig_pathjump_allow.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2014 Ralf Hoffmann.
+ * Copyright (C) 2012-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,9 +23,9 @@
 #include "wconfig.h"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/fieldlistview.h>
-#include <aguix/button.h>
-#include <aguix/choosebutton.h>
+#include "aguix/fieldlistview.h"
+#include "aguix/button.h"
+#include "aguix/choosebutton.h"
 #include "datei.h"
 #include "nwc_path.hh"
 
@@ -56,6 +56,8 @@ int PathJumpAllowPanel::create()
     m_lv =(FieldListView*)ac1->add( new FieldListView( _aguix, 0, 0, 100, 100, 0 ), 0, 1, AContainer::CO_MIN );
     m_lv->setHBarState(2);
     m_lv->setVBarState(2);
+    m_lv->setAcceptFocus( true );
+    m_lv->setDisplayFocus( true );
 
     AContainer *ac1_1 = ac1->add( new AContainer( this, 2, 1 ), 0, 2 );
     ac1_1->setMinSpace( 0 );
