@@ -93,7 +93,7 @@ extern "C" {
 #include <regex.h>
 #endif
 
-#include <aguix/aguixdefs.h>
+#include "aguix/aguixdefs.h"
 
 #ifdef HAVE_LIBZ
   #include <zlib.h>
