@@ -30,7 +30,7 @@
 #include "timedtext.hh"
 #include "processhandler.hh"
 #include <map>
-#include <aguix/message.h>
+#include "aguix/message.h"
 #include "hw_volume_manager.hh"
 #include <memory>
 #include "event_callbacks.hh"
@@ -134,13 +134,13 @@ public:
   AWindow *getMainWin();
   void setStatebarText(const char*);
   static int getNrOfCommands();
-  static FunctionProto *getCommand4ID(int);
+  static std::shared_ptr< FunctionProto > getCommand4ID(int);
   static int getID4Command(FunctionProto*);
   Lister *getOtherLister(Lister*);
   int getSide(Lister*);
   Lister *getLister(int);
   Lister *getActiveLister();
-  int interpret(List*,ActionMessage *);
+  int interpret( const command_list_t &,ActionMessage *);
   AWindow *getListerWin( Lister *l );
   
   int quit(int mode);
@@ -441,7 +441,7 @@ protected:
 
     void prepareMenuTree( MenuTreeUI &menuui );
     void initWorkerTextMenu( MenuTreeNode *menu );
-    bool checkCommandListForCommand( List *list, const std::string &name );
+    bool checkCommandListForCommand( const command_list_t &list, const std::string &name );
 
     void updateRunningVersion();
 
