@@ -28,7 +28,7 @@ int Worker::getNrOfCommands()
   return 58;
 }
 
-FunctionProto *Worker::getCommand4ID(int id)
+std::shared_ptr< FunctionProto > Worker::getCommand4ID(int id)
 {
   FunctionProto *fpr=NULL;
   switch(id) {
@@ -202,7 +202,7 @@ FunctionProto *Worker::getCommand4ID(int id)
     default:
       fpr=new DNDAction();
   }
-  return fpr;
+  return std::shared_ptr< FunctionProto >( fpr );
 }
 
 int Worker::getID4Command(FunctionProto *fpr)
