@@ -22,12 +22,12 @@
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
-#include <aguix/utf8.hh>
+#include "aguix/utf8.hh"
 #include "workerinitialsettings.hh"
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1356
+#define CATENTRY 1370
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -1280,11 +1280,11 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1177]=dupstring( "Show non-printable characters as hexadecimal representation\ninstead of a simple dot replacement" );
   catalog[1178]=dupstring( "Show in list view" );
   catalog[1179]=dupstring( "Open a new tab in the current list view and highlight the currently viewed file" );
-  catalog[1180]=dupstring( "Compare the directory in the active and inactive panel based on the criterion selected below. The equal entries will be selected in the active panel (and the unequal entries will be unselected). The inactive panel works inverse, so that all unequal entries will be selected and the equal ones will be unselected. You can also choose to show the results in virtual directories. In this case the active panel will be a virtual directory will all equal files and directories while the inactive panel will be a virtual directory with all unequal elements." );
-  catalog[1181]=dupstring( "How to compare files:" );
-  catalog[1182]=dupstring( "Fast comparison with file size only" );
-  catalog[1183]=dupstring( "Compare size and modification time" );
-  catalog[1184]=dupstring( "Slow comparison with content" );
+  catalog[1180]=dupstring( "Compare the directory in the active and inactive panel based on the criterion selected below.\n\nActive side: The equal entries will be selected (and the unequal entries will be unselected).\n\nInactive side: All equal entries will be deselected and all unequal ones will be selected (inverse to active side).\n\nYou can also choose to show the results in virtual directories. In this case the active panel will be a virtual directory will all equal files and directories while the inactive panel will be a virtual directory with all unequal elements." );
+  catalog[1181]=dupstring( "" );
+  catalog[1182]=dupstring( "" );
+  catalog[1183]=dupstring( "" );
+  catalog[1184]=dupstring( "" );
   catalog[1185]=dupstring( "How to use result:" );
   catalog[1186]=dupstring( "Change selection state" );
   catalog[1187]=dupstring( "Show as virtual directories" );
@@ -1457,6 +1457,20 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1353]=dupstring( "Button '%s'" );
   catalog[1354]=dupstring( "Hotkey '%s'" );
   catalog[1355]=dupstring( "Path button '%s'" );
+  catalog[1356]=dupstring( "High" );
+  catalog[1357]=dupstring( "Default" );
+  catalog[1358]=dupstring( "Low" );
+  catalog[1359]=dupstring( "File type priority:" );
+  catalog[1360]=dupstring( "Priority" );
+  catalog[1361]=dupstring( "File name and content" );
+  catalog[1362]=dupstring( "File size" );
+  catalog[1363]=dupstring( "File checksum" );
+  catalog[1364]=dupstring( "Max number of bytes to check:" );
+  catalog[1365]=dupstring( "Checksum feature not available due to missing OpenSSL" );
+  catalog[1366]=dupstring( "Files are equal on same:" );
+  catalog[1367]=dupstring( "File name" );
+  catalog[1368]=dupstring( "File name and file size" );
+  catalog[1369]=dupstring( "File name, size, and modification time" );
 
 //  catalog[]=dupstring( "" );
   
