@@ -1,6 +1,6 @@
 /* wpucontext.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2014 Ralf Hoffmann.
+ * Copyright (C) 2002-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,11 +27,11 @@
 #include "worker.h"
 #include "dnd.h"
 #include "worker_locale.h"
-#include <aguix/aguix.h>
-#include <aguix/solidbutton.h>
-#include <aguix/button.h>
-#include <aguix/awindow.h>
-#include <aguix/bevelbox.h>
+#include "aguix/aguix.h"
+#include "aguix/solidbutton.h"
+#include "aguix/button.h"
+#include "aguix/awindow.h"
+#include "aguix/bevelbox.h"
 #include "datei.h"
 #include <iostream>
 #include "nmexternfe.hh"
@@ -116,26 +116,16 @@ struct wpucontext_deftokens {
 };
 
 //TODO vielleicht auch noch ONLYACTIVE untersttzen
-WPUContext::WPUContext( Worker *w, List *coms, bool delete_commands_at_destroy, ActionMessage *msg )
+WPUContext::WPUContext( Worker *w, const command_list_t &coms, ActionMessage *msg ) : acoms( coms )
 {
-  int id;
-  FunctionProto *fp;
   struct wpucontext_deftokens *p;
 
   m_reference_count = 1;
   nr_of_stacks = 0;
   stacks = NULL;
   pc = 0;
-  acoms = new ArrayList();
-  m_delete_commands_at_destroy = delete_commands_at_destroy;
-  
-  id = coms->initEnum();
-  fp = (FunctionProto*)coms->getFirstElement( id );
-  while ( fp != NULL ) {
-    acoms->addElement( fp );
-    fp = (FunctionProto*)coms->getNextElement( id );
-  }
-  coms->closeEnum( id );
+
+  acoms = coms;
 
   extlist[0] = NULL;
   extlist[1] = NULL;
@@ -211,20 +201,6 @@ WPUContext::~WPUContext()
 {
   closeWin();
 
-  if ( m_delete_commands_at_destroy ) {
-      int id;
-      FunctionProto *fp1;
-
-      id = acoms->initEnum();
-      fp1 = (FunctionProto*)acoms->getFirstElement( id );
-      while ( fp1 != NULL ) {
-          delete fp1;
-          fp1 = (FunctionProto*)acoms->getNextElement( id );
-      }
-      acoms->closeEnum( id );
-  }
-
-  delete acoms;
   for ( int i = 0; i < nr_of_stacks; i++ ) {
     delete stacks[i];
   }
@@ -240,32 +216,26 @@ WPUContext::~WPUContext()
 int WPUContext::continueAtLabel( const char *label )
 {
   /* find label and set pc to position */
-  int pos, id;
-  FunctionProto *fp;
-  ScriptOp *sop;
-  
-  pos = 0;
+  size_t pos = 0;
   // whithout useful label jump to the end to avoid problems
   if ( label != NULL ) {
     if ( strlen( label ) > 0 ) {
-      id = acoms->initEnum();
-      while ( pos < acoms->size() ) {
-        fp = (FunctionProto*)acoms->getElementAt( id, pos );
-        if ( strcmp( fp->getName(), "ScriptOp" ) == 0 ) {
-          sop = (ScriptOp*)fp;
-          if ( sop->isLabel( label ) == true ) {
-             break;
+      while ( pos < acoms.size() ) {
+          auto &fp = acoms.at( pos );
+          if ( strcmp( fp->getName(), "ScriptOp" ) == 0 ) {
+              auto sop = std::dynamic_pointer_cast< ScriptOp >( fp );
+              if ( sop->isLabel( label ) == true ) {
+                  break;
+              }
           }
-        }
-        pos++;
+          pos++;
       }
-      acoms->closeEnum( id );
-    } else pos = acoms->size();
-  } else pos = acoms->size();
+    } else pos = acoms.size();
+  } else pos = acoms.size();
   pc = pos;  /* when label was not found, finish whole execution
                 because it's a error in list and I don't want to
                 do something wrong */
-  if ( pc >= acoms->size() ) return 1;
+  if ( pc >= acoms.size() ) return 1;
   return 0;
 }
 
@@ -309,14 +279,13 @@ int WPUContext::size( int nr )
 
 int WPUContext::next( ActionMessage *msg )
 {
-  FunctionProto *fp;
   AGUIX *aguix = worker->getAGUIX();
   AGMessage *agmsg;
   bool cancel = false;
 
-  if ( pc >= acoms->size() ) return 1;
-  fp = (FunctionProto*)acoms->getElementAt( pc );
-  if ( fp != NULL ) {
+  if ( pc >= acoms.size() ) return 1;
+  auto &fp = acoms.at( pc );
+  if ( fp ) {
     fp->run( this, msg );
     pc++;
     
