@@ -1,6 +1,6 @@
 /* wpucontext.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2019 Ralf Hoffmann.
+ * Copyright (C) 2002-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,16 +24,16 @@
 
 #include "wdefines.h"
 #include <string>
-#include <aguix/util.h>
-#include <aguix/lowlevelfunc.h>
+#include "aguix/util.h"
+#include "aguix/lowlevelfunc.h"
 #include "temporaryfilecache.hh"
 #include "datei.h"
 #include "timedtext.hh"
 #include "nmextlist.hh"
-#include <aguix/refcount.hh>
+#include "aguix/refcount.hh"
+#include "functionproto.h"
 
 class Worker;
-class ArrayList;
 class SolidButton;
 class Text;
 class BevelBox;
@@ -81,7 +81,7 @@ protected:
 class WPUContext
 {
 public:
-  WPUContext( Worker *, List *coms, bool delete_commands_at_destroy, ActionMessage *msg );
+  WPUContext( Worker *, const command_list_t &coms, ActionMessage *msg );
   ~WPUContext();
   WPUContext( const WPUContext &other );
   WPUContext &operator=( const WPUContext &other );
@@ -171,8 +171,8 @@ public:
     const std::string &getPathDBFilename() const;
 private:
   WPUStack **stacks;
-  ArrayList *acoms;
-  int pc;
+  command_list_t acoms;
+  size_t pc;
   int nr_of_stacks;
   void buildStack( int nr );
   
@@ -241,7 +241,6 @@ private:
   };
   std::list<class temp4filename_t*> tempnamelist;
 
-  bool m_delete_commands_at_destroy;
   int m_reference_count;
 
   std::list< TemporaryFileCache::TemporaryFileCacheEntry > m_temp_files;
